@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2003 the xine project
+ * Copyright (C) 2000-2004 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: utils.c,v 1.24 2003/12/18 00:30:11 f1rmb Exp $
+ * $Id: utils.c,v 1.31 2004/04/15 20:55:36 f1rmb Exp $
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -158,7 +158,7 @@ static int _mkdir_safe(char *path) {
   if(path == NULL)
     return 0;
   
-  if((lstat(path, &pstat)) < 0) {
+  if((stat(path, &pstat)) < 0) {
     /* file or directory no exist, create it */
     if(mkdir(path, 0755) < 0) {
       fprintf(stderr, "mkdir(%s) failed: %s\n", path, strerror(errno));
@@ -327,7 +327,14 @@ int is_ipv6_last_double_semicolon(const char *str) {
   return 0;
 }
 
-inline int is_a_dir(char *filename) {
+int is_downloadable(char *filename) {
+  if(filename && 
+     ((!strncasecmp(filename, "http://", 7)) || (!strncasecmp(filename, "ftp://", 6))))
+    return 1;
+  return 0;
+}
+
+int is_a_dir(char *filename) {
   struct stat  pstat;
   
   if((stat(filename, &pstat)) < 0)
@@ -336,7 +343,7 @@ inline int is_a_dir(char *filename) {
   return (S_ISDIR(pstat.st_mode));
 }
 
-inline int is_a_file(char *filename) {
+int is_a_file(char *filename) {
   struct stat  pstat;
   
   if((stat(filename, &pstat)) < 0)
@@ -823,4 +830,21 @@ void dump_xfree_info(Display *display, int screen, int complete) {
     }
   }
 }
+
 #endif /* !HAVE_X11 */
+
+void dump_error(int verbosity, char *msg) {
+  if(verbosity) {
+    fprintf(stderr, "%s", "\n---------------------- (ERROR) ----------------------\n");
+    fputs(msg, stderr); 
+    fprintf(stderr, "%s","\n------------------ (END OF ERROR) -------------------\n\n");
+  }
+}
+
+void dump_info(int verbosity, char *msg) {
+  if(verbosity) {
+    fprintf(stderr, "%s", "\n---------------------- (INFO) ----------------------\n");
+    fputs(msg, stderr);
+    fprintf(stderr, "%s", "\n------------------- (END OF INFO) ------------------\n\n");
+  }
+}
