@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2003 the xine project
+ * Copyright (C) 2000-2004 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: control.h,v 1.12 2003/04/09 20:58:37 f1rmb Exp $
+ * $Id: control.h,v 1.17 2004/11/22 08:45:26 f1rmb Exp $
  *
  */
 
@@ -28,13 +28,15 @@ void control_config_register(void);
 
 void control_deinit(void);
 void control_panel(void);
-void control_change_skins(void);
+void control_change_skins(int);
 void control_exit(xitk_widget_t *, void *);
 int control_is_visible(void);
 int control_is_running(void);
 void control_toggle_visibility(xitk_widget_t *, void *);
 void control_raise_window(void);
 void control_show_tips(int enabled, unsigned long timeout);
+void control_update_tips_timeout(unsigned long timeout);
 void control_set_image_prop(int prop, int value);
+void control_reparent(void);
 
 #endif
