@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: event.c,v 1.256 2004/07/02 21:41:02 f1rmb Exp $
+ * $Id: event.c,v 1.271 2004/12/16 16:14:08 f1rmb Exp $
  *
  * gui initialization and top-level event handling stuff
  *
@@ -111,9 +111,9 @@ int hidden_file_cb(int action, int value) {
   xine_cfg_entry_t  cfg_entry;
   int               retval = 0;
   
-  if(xine_config_lookup_entry(gGui->xine, "input.file_hidden_files", &cfg_entry)) {
+  if(xine_config_lookup_entry(gGui->xine, "media.files.show_hidden_files", &cfg_entry)) {
     if(action)
-      config_update_bool("input.file_hidden_files", value);
+      config_update_bool("media.files.show_hidden_files", value);
     else
       retval = cfg_entry.num_value;
   }
@@ -140,10 +140,44 @@ static void ssaver_timeout_cb(void *data, xine_cfg_entry_t *cfg) {
 
 static void visual_anim_cb(void *data, xine_cfg_entry_t *cfg) {
   
-  if(((gGui->visual_anim.enabled == 2) && (cfg->num_value != 2)) && gGui->visual_anim.running)
-     visual_anim_stop();
+  if(gGui->visual_anim.enabled == cfg->num_value)
+    return;
+
+  if((gGui->visual_anim.enabled) && (cfg->num_value == 0) && gGui->visual_anim.running)
+    visual_anim_stop();
+  
+  if(gGui->visual_anim.enabled && gGui->visual_anim.running) {
+    if((gGui->visual_anim.enabled == 1) && (cfg->num_value != 1)) {
+      if(post_rewire_audio_port_to_stream(gGui->stream))
+	gGui->visual_anim.running = 0;
+    }
+    if((gGui->visual_anim.enabled == 2) && (cfg->num_value != 2)) {
+      visual_anim_stop();
+      gGui->visual_anim.running = 0;
+    }
+  }
   
   gGui->visual_anim.enabled = cfg->num_value;
+  
+  if(gGui->visual_anim.enabled) {
+    int  has_video = xine_get_stream_info(gGui->stream, XINE_STREAM_INFO_HAS_VIDEO);
+    
+    if(has_video)
+      has_video = !xine_get_stream_info(gGui->stream, XINE_STREAM_INFO_IGNORE_VIDEO);
+    
+    if(!has_video && !gGui->visual_anim.running) {
+      if(gGui->visual_anim.enabled == 1) {
+	if(gGui->visual_anim.post_output) {
+	  if(post_rewire_audio_post_to_stream(gGui->stream))
+	    gGui->visual_anim.running = 1;
+	}
+      }
+      else if(gGui->visual_anim.enabled == 2) {
+	visual_anim_play();
+	gGui->visual_anim.running = 1;
+      }
+    }
+  }
 }
 
 static void stream_info_auto_update_cb(void *data, xine_cfg_entry_t *cfg) {
@@ -416,9 +450,13 @@ void gui_execute_action_id(action_id_t action) {
     break;
     
   case ACTID_TOGGLE_WINOUT_VISIBLITY:
-    gui_toggle_visibility (NULL, NULL);
+    gui_toggle_visibility(NULL, NULL);
     break;
     
+  case ACTID_TOGGLE_WINOUT_BORDER:
+    gui_toggle_border(NULL, NULL);
+    break;
+
   case ACTID_AUDIOCHAN_NEXT:
     if(!gGui->numeric.set)
       gui_change_audio_channel(NULL, (void*)GUI_NEXT);
@@ -1018,13 +1056,11 @@ void gui_playlist_start_next(void) {
                                    gGui->mmk.start, gGui->mmk.av_offset, gGui->mmk.spu_offset, 
                                    !mediamark_have_alternates(&(gGui->mmk)))) {
           
-          if(!mediamark_have_alternates(&(gGui->mmk)) ||
-             !gui_open_and_play_alternates(&(gGui->mmk), gGui->mmk.sub)) {
-              gui_display_logo();
+          if(!mediamark_have_alternates(&(gGui->mmk)) || !gui_open_and_play_alternates(&(gGui->mmk), gGui->mmk.sub)) {
             if(mediamark_all_played() && (gGui->actions_on_start[0] == ACTID_QUIT))
               gui_exit(NULL, NULL);
-            
-            gui_display_logo();
+	    
+	    gui_display_logo();
           }
         }
       }
@@ -1040,6 +1076,7 @@ void gui_playlist_start_next(void) {
       if(mediamark_have_alternates(&(gGui->mmk))) {
         if(!gui_open_and_play_alternates(&(gGui->mmk), gGui->mmk.sub))
           gui_display_logo();
+
       }
     }
     break;
@@ -1190,7 +1227,6 @@ void gui_init (int nfiles, char *filenames[], window_attributes_t *window_attrib
    * init playlist
    */
   for (i = 0; i < nfiles; i++) {
-    char *sub = NULL;
     char *file = atoa(filenames[i]);
 
     /* grab recursively all files from dir */
@@ -1198,22 +1234,31 @@ void gui_init (int nfiles, char *filenames[], window_attributes_t *window_attrib
       
       if(file[strlen(file) - 1] == '/')
 	file[strlen(file) - 1] = '\0'; 
-      
+
       mediamark_collect_from_directory(file);
     }
     else {
-      if((sub = (char *)get_last_double_semicolon(file)) != NULL) {
-	if(is_ipv6_last_double_semicolon(file))
-	  sub = NULL;
-	else {
-	  *sub = 0;
-	  sub += 2;
+
+      if(mrl_look_like_playlist(file))
+	(void) mediamark_concat_mediamarks(file);
+      else {
+	char *sub = NULL;
+
+	if((sub = (char *)get_last_double_semicolon(file)) != NULL) {
+	  if(is_ipv6_last_double_semicolon(file))
+	    sub = NULL;
+	  else {
+	    *sub = 0;
+	    sub += 2;
+	  }
 	}
+	
+	mediamark_append_entry((const char *)file, (const char *)file, sub, 0, -1, 0, 0);
       }
-      
-      mediamark_append_entry((const char *)file, (const char *)file, sub, 0, -1, 0, 0);
     }
   }
+
+  gGui->playlist.cur = gGui->playlist.num ? 0 : -1;
   
   if((gGui->playlist.loop == PLAYLIST_LOOP_SHUFFLE) || 
      (gGui->playlist.loop == PLAYLIST_LOOP_SHUF_PLUS))
@@ -1227,10 +1272,10 @@ void gui_init (int nfiles, char *filenames[], window_attributes_t *window_attrib
    * X / imlib stuff
    */
 
-  if (!XInitThreads ()) {
+  if(!XInitThreads()) {
     printf (_("\nXInitThreads failed - looks like you don't have a "
 	    "thread-safe xlib.\n"));
-    exit (1);
+    exit(1);
   } 
   
   if((gGui->display = XOpenDisplay((getenv("DISPLAY")))) == NULL) {
@@ -1501,7 +1546,7 @@ void gui_init (int nfiles, char *filenames[], window_attributes_t *window_attrib
    */
   xine_pid = getppid();
   
-  xitk_init(gGui->display, (gGui->verbosity) ? 1 : 0);
+  xitk_init(gGui->display, gGui->black, (gGui->verbosity) ? 1 : 0);
   
   preinit_skins_support();
   
@@ -1523,7 +1568,7 @@ void gui_init (int nfiles, char *filenames[], window_attributes_t *window_attrib
 
   gui_set_current_mmk(mediamark_get_current_mmk());
 
-  panel_init ();
+  panel_init();
 }
 
 void gui_init_imlib (Visual *vis) {
@@ -1587,7 +1632,7 @@ static void on_start(void *data) {
   splash_destroy();
 
   if((!startup->start && !gGui->playlist.num) || (!startup->start && gGui->playlist.num)) {
-
+    
     gui_display_logo();
     
     do {
@@ -1596,27 +1641,12 @@ static void on_start(void *data) {
 
   }
 
-  /* Crapy Workaround:
-   * The lib seems unable to display OSD until the stream got 
-   * any video data.
-   */
-  if(startup->start || (!startup->start && !gGui->display_logo)) {
-    (void) xine_open(gGui->stream, (const char *) XINE_BLACK_STREAM);
-    
-    if(!startup->start && !gGui->display_logo)
-      xine_play(gGui->stream, 0, 0);
-    
-    gGui->ignore_next = 1;
-    xine_stop(gGui->stream);
-    gGui->ignore_next = 0;
-  }
-  
   if(startup->session_opts) {
     int i = 0;
     int dummy_session;
     
     while(startup->session_opts[i])
-      session_handle_subopt(startup->session_opts[i++], &dummy_session);
+      (void) session_handle_subopt(startup->session_opts[i++], &dummy_session);
     
   }
   
@@ -1629,8 +1659,9 @@ void gui_run(char **session_opts) {
   _startup_t  startup;
   int         i, auto_start = 0;
   
-  video_window_change_skins();
+  video_window_change_skins(0);
   panel_add_autoplay_buttons();
+  panel_show_tips();
   panel_add_mixer_control();
   panel_update_channel_display () ;
   panel_update_mrl_display ();
@@ -1741,10 +1772,13 @@ void gui_run(char **session_opts) {
 
     /* User load a playlist on startup */
     if(actions_on_start(gGui->actions_on_start, ACTID_PLAYLIST)) {
-      mediamark_load_mediamarks(gGui->playlist.on_start);
       gui_set_current_mmk(mediamark_get_current_mmk());
-      if((!is_playback_widgets_enabled()) && gGui->playlist.num)
-	enable_playback_controls(1);
+
+      if(gGui->playlist.num) {
+	gGui->playlist.cur = 0;
+	if(!is_playback_widgets_enabled())
+	  enable_playback_controls(1);
+      }
     }
 
     if(actions_on_start(gGui->actions_on_start, ACTID_TOGGLE_INTERLEAVE))
