@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: event_sender.h,v 1.10 2004/06/13 11:44:13 f1rmb Exp $
+ * $Id: event_sender.h,v 1.11 2004/07/21 19:56:16 f1rmb Exp $
  *
  */
 
@@ -35,5 +35,7 @@ void event_sender_raise_window(void);
 void event_sender_update_menu_buttons(void);
 void event_sender_send(int event);
 void event_sender_reparent(void);
+void event_sender_show_tips(int enabled, unsigned long timeout);
+void event_sender_update_tips_timeout(unsigned long timeout);
 
 #endif
