@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: kbindings.h,v 1.53 2004/06/13 11:44:17 f1rmb Exp $
+ * $Id: kbindings.h,v 1.55 2004/12/16 16:14:09 f1rmb Exp $
  *
  */
 #ifndef KBINDINGS_H
@@ -48,6 +48,7 @@ typedef enum {
   ACTID_SPU_PRIOR,
   ACTID_CONTROLSHOW,
   ACTID_TOGGLE_WINOUT_VISIBLITY,
+  ACTID_TOGGLE_WINOUT_BORDER,
   ACTID_AUDIOCHAN_NEXT,
   ACTID_AUDIOCHAN_PRIOR,
   ACTID_PLAYLIST,
@@ -172,6 +173,42 @@ typedef enum {
   ACTID_EVENT_NUMBER_8      = XINE_EVENT_INPUT_NUMBER_8       | ACTID_IS_INPUT_EVENT,
   ACTID_EVENT_NUMBER_9      = XINE_EVENT_INPUT_NUMBER_9       | ACTID_IS_INPUT_EVENT,
   ACTID_EVENT_NUMBER_10_ADD = XINE_EVENT_INPUT_NUMBER_10_ADD  | ACTID_IS_INPUT_EVENT
+#ifdef ENABLE_VDR_KEYS
+,
+  ACTID_EVENT_VDR_RED           = XINE_EVENT_VDR_RED              | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_GREEN         = XINE_EVENT_VDR_GREEN            | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_YELLOW        = XINE_EVENT_VDR_YELLOW           | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_BLUE          = XINE_EVENT_VDR_BLUE             | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_PLAY          = XINE_EVENT_VDR_PLAY             | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_PAUSE         = XINE_EVENT_VDR_PAUSE            | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_STOP          = XINE_EVENT_VDR_STOP             | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_RECORD        = XINE_EVENT_VDR_RECORD           | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_FASTFWD       = XINE_EVENT_VDR_FASTFWD          | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_FASTREW       = XINE_EVENT_VDR_FASTREW          | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_POWER         = XINE_EVENT_VDR_POWER            | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_CHANNELPLUS   = XINE_EVENT_VDR_CHANNELPLUS      | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_CHANNELMINUS  = XINE_EVENT_VDR_CHANNELMINUS     | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_SCHEDULE      = XINE_EVENT_VDR_SCHEDULE         | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_CHANNELS      = XINE_EVENT_VDR_CHANNELS         | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_TIMERS        = XINE_EVENT_VDR_TIMERS           | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_RECORDINGS    = XINE_EVENT_VDR_RECORDINGS       | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_SETUP         = XINE_EVENT_VDR_SETUP            | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_COMMANDS      = XINE_EVENT_VDR_COMMANDS         | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_BACK          = XINE_EVENT_VDR_BACK             | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_USER1         = XINE_EVENT_VDR_USER1            | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_USER2         = XINE_EVENT_VDR_USER2            | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_USER3         = XINE_EVENT_VDR_USER3            | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_USER4         = XINE_EVENT_VDR_USER4            | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_USER5         = XINE_EVENT_VDR_USER5            | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_USER6         = XINE_EVENT_VDR_USER6            | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_USER7         = XINE_EVENT_VDR_USER7            | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_USER8         = XINE_EVENT_VDR_USER8            | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_USER9         = XINE_EVENT_VDR_USER9            | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_VOLPLUS       = XINE_EVENT_VDR_VOLPLUS          | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_VOLMINUS      = XINE_EVENT_VDR_VOLMINUS         | ACTID_IS_INPUT_EVENT,
+  ACTID_EVENT_VDR_MUTE          = XINE_EVENT_VDR_MUTE             | ACTID_IS_INPUT_EVENT
+#endif
+
   /*
    * End of numeric mapping.
    */
