@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: main.c,v 1.293 2004/07/02 21:41:03 f1rmb Exp $
+ * $Id: main.c,v 1.301 2004/12/15 21:10:45 f1rmb Exp $
  *
  * xine main for X11
  *
@@ -87,7 +87,7 @@ typedef struct {
 
 #define	OPTION_VISUAL		1000
 #define	OPTION_INSTALL_COLORMAP	1001
-#define DISPLAY_KEYMAP          1002
+#define OPTION_DISPLAY_KEYMAP   1002
 #define OPTION_SK_SERVER        1003
 #define OPTION_ENQUEUE          1004
 #define OPTION_VERBOSE          1005
@@ -99,6 +99,7 @@ typedef struct {
 #define OPTION_STDCTL           1011
 #define OPTION_LIST_PLUGINS     1012
 #define OPTION_BUG_REPORT       1013
+#define OPTION_NETWORK_PORT     1014
 
 
 /* options args */
@@ -133,8 +134,9 @@ static struct option long_options[] = {
 #endif
   {"visual"	    , required_argument, 0,  OPTION_VISUAL           },
   {"install"	    , no_argument      , 0,  OPTION_INSTALL_COLORMAP },
-  {"keymap"         , optional_argument, 0,  DISPLAY_KEYMAP          },
+  {"keymap"         , optional_argument, 0,  OPTION_DISPLAY_KEYMAP   },
   {"network"        , no_argument      , 0, 'n'                      },
+  {"network-port"   , required_argument, 0,  OPTION_NETWORK_PORT     },
   {"root"           , no_argument      , 0, 'R'                      },
   {"geometry"       , required_argument, 0, 'G'                      },
   {"borderless"     , no_argument      , 0, 'B'                      },
@@ -636,6 +638,7 @@ static void show_usage (void) {
 	   "                                 'file:<filename>': use <filename> as keymap.\n"
 	   "                                 -if no option is given, 'default' is selected.\n"));
   printf(_("  -n, --network                Enable network remote control server.\n"));
+  printf(_("      --network-port           Specify network server port number.\n"));
   printf(_("  -R, --root                   Use root window as video window.\n"));
   printf(_("  -G, --geometry <WxH[+X+Y]>   Set output window geometry (X style).\n"));
   printf(_("  -B, --borderless             Borderless video output window.\n"));
@@ -658,6 +661,7 @@ static void show_usage (void) {
 	   "                    volume=v    set audio volume,\n"
 	   "                    amp=v       set amplification level,\n"
 	   "                    loop=m      set loop mode (<m>: 'none' 'loop' 'repeat' 'shuffle' or 'shuffle+'),\n"
+           "                    get_speed   get speed value (see man page for returned value).\n"
 	   "                    (playlist|pl)=p\n"
 	   "                                 <p> can be:\n"
 	   "                                   'clear'  clear the playlist,\n"
@@ -842,19 +846,12 @@ static xine_video_port_t *load_video_out_driver(int driver_number) {
 					  video_driver_ids[driver_number],
 					  XINE_VISUAL_TYPE_FB, NULL);
 
-      /* save requested driver (-V) */ 
-      if(video_port)
-        config_update_num("video.driver", driver_number);
     }
     else {
       video_port = xine_open_video_driver(gGui->xine,
 					  video_driver_ids[driver_number],
 					  XINE_VISUAL_TYPE_X11, 
 					  (void *) &vis);
-      
-      /* save requested driver (-V) */ 
-      if(video_port)
-        config_update_num("video.driver", driver_number);
     }
     
     if(!video_port) {
@@ -969,11 +966,9 @@ static xine_audio_port_t *load_audio_out_driver(int driver_number) {
 
       if (!audio_port) {
         printf (_("main: audio driver <%s> failed\n"), audio_driver_ids[driver_number]);
-        exit (1);
+        exit(1);
       }
     
-      /* save requested driver (-A) */ 
-      config_update_num("audio.driver", driver_number);
     }
   
   }
@@ -1316,6 +1311,7 @@ int main(int argc, char *argv[]) {
   int                     enable_deinterlace = 0;
   char                  **session_argv     = NULL;
   int                     session_argv_num = 0;
+  int                     retval           = 0;
   
 #ifdef HAVE_SETLOCALE
   if((xitk_set_locale()) != NULL)
@@ -1351,14 +1347,15 @@ int main(int argc, char *argv[]) {
   gGui->install_colormap       = 0;
   gGui->cursor_grabbed         = 0;
   gGui->network                = 0;
+  gGui->network_port           = 0;
   gGui->video_window           = None;
   gGui->use_root_window        = 0;
 #ifdef HAVE_XF86VIDMODE
   gGui->XF86VidMode_fullscreen = 0;
 #endif
   gGui->actions_on_start[aos]  = ACTID_NOKEY;
+  gGui->playlist.mmk           = NULL;
   gGui->playlist.loop          = PLAYLIST_LOOP_NO_LOOP;
-  gGui->playlist.on_start      = NULL;
   gGui->playlist.control       = 0;
   gGui->skin_server_url        = NULL;
   gGui->verbosity              = 0;
@@ -1538,7 +1535,7 @@ int main(int argc, char *argv[]) {
       gGui->install_colormap = 1;
       break;
 
-    case DISPLAY_KEYMAP:
+    case OPTION_DISPLAY_KEYMAP:
       if(optarg != NULL) {
 	char *p = xine_chomp(optarg);
 
@@ -1572,6 +1569,18 @@ int main(int argc, char *argv[]) {
       gGui->network = 1;
       break;
       
+    case OPTION_NETWORK_PORT:
+      if(optarg) {
+	int port = strtol(optarg, &optarg, 10);
+
+	if((port >= 1) && (port <= 65535))
+	  gGui->network_port = port;
+	else
+	  printf(_("Bad port number: %d\n"), port);
+
+      }
+      break;
+
     case 'R': /* Use root window for video output */
       gGui->use_root_window = 1;
       break;
@@ -1594,10 +1603,13 @@ int main(int argc, char *argv[]) {
       break;
 
     case 'P':
-      if(aos < MAX_ACTIONS_ON_START) {
+      if((!actions_on_start(gGui->actions_on_start, ACTID_PLAYLIST) && (aos < MAX_ACTIONS_ON_START)))
 	gGui->actions_on_start[aos++] = ACTID_PLAYLIST;
-	gGui->playlist.on_start = strdup(optarg);
-      }
+      
+      if(!gGui->playlist.mmk)
+	mediamark_load_mediamarks(optarg);
+      else
+	mediamark_concat_mediamarks(optarg);
       break;
 
     case 'l':
@@ -1653,9 +1665,9 @@ int main(int argc, char *argv[]) {
 
     case 'S':
       if(is_remote_running(((session >= 0) ? session : 0)))
-	session_handle_subopt(optarg, &session);
+	retval = session_handle_subopt(optarg, &session);
       else {
-
+	
 	session_argv = (char **) realloc(session_argv, sizeof(char *) * (session_argv_num + 2));
 
 	session_argv[session_argv_num++] = strdup(optarg);
@@ -1794,7 +1806,7 @@ int main(int argc, char *argv[]) {
 	  char enqueue_mrl[strlen(_argv[i]) + 256];
 
 	  sprintf(enqueue_mrl, "session=%d,mrl=%s", session, atoa(_argv[i]));
-	  session_handle_subopt(enqueue_mrl, &session);
+	  (void) session_handle_subopt(enqueue_mrl, &session);
 	}
       }
       else
@@ -1803,7 +1815,8 @@ int main(int argc, char *argv[]) {
     }
 
     free_command_line_args(&_argv, _argc);
-    return 0;
+
+    return retval;
   }
 
   /* 
@@ -1818,6 +1831,19 @@ int main(int argc, char *argv[]) {
   
   show_banner();
   
+#ifndef DEBUG
+  if(!gGui->verbosity) {
+    int error_fd;
+    
+    if ((error_fd = open("/dev/null", O_WRONLY)) < 0)
+      printf("cannot open /dev/null");
+    else {
+      if (dup2(error_fd, STDOUT_FILENO) < 0)
+	printf("cannot dup2 stdout");
+    }
+  }
+#endif
+
   /*
    * Initialize config
    */
@@ -1928,7 +1954,7 @@ int main(int argc, char *argv[]) {
   {
     xine_cfg_entry_t  cfg_entry;
     
-    if(xine_config_lookup_entry(gGui->xine, "input.file_origin_path", &cfg_entry))
+    if(xine_config_lookup_entry(gGui->xine, "media.files.origin_path", &cfg_entry))
       snprintf(gGui->curdir, sizeof(gGui->curdir), "%s", cfg_entry.str_value);
     else
       (void *) getcwd(&(gGui->curdir[0]), XITK_PATH_MAX);
@@ -1975,7 +2001,7 @@ int main(int argc, char *argv[]) {
       if(!strcasecmp(video_driver_ids[cfg_vo_entry.num_value], "dxr3")) {
 	xine_cfg_entry_t  cfg_entry;
 	
-	if(xine_config_lookup_entry(gGui->xine, "dxr3.videoout_mode", &cfg_entry)) {
+	if(xine_config_lookup_entry(gGui->xine, "dxr3.output.mode", &cfg_entry)) {
 	  if(((!strcmp(cfg_entry.enum_values[cfg_entry.num_value], "letterboxed tv")) ||
 	      (!strcmp(cfg_entry.enum_values[cfg_entry.num_value], "widescreen tv"))) && 
 	     (!(actions_on_start(gGui->actions_on_start, ACTID_TOGGLE_WINOUT_VISIBLITY)))) {
@@ -2020,7 +2046,7 @@ int main(int argc, char *argv[]) {
 	}
       }
     }
-    gGui->ao_port = load_audio_out_driver(driver_num);
+    gGui->ao_port = load_audio_out_driver(driver_num);    
   }
   SAFE_FREE(audio_driver_id);
 
@@ -2028,7 +2054,11 @@ int main(int argc, char *argv[]) {
   post_init();
 
   gGui->stream = xine_stream_new(gGui->xine, gGui->ao_port, gGui->vo_port);
-  
+
+  /* Store audio mixer level */
+  if(gGui->ao_port && (gGui->mixer.method == SOUND_CARD_MIXER))
+    gGui->mixer.original_level = xine_get_param(gGui->stream, XINE_PARAM_AUDIO_VOLUME);
+
   gGui->vo_none = xine_open_video_driver(gGui->xine, "none", XINE_VISUAL_TYPE_NONE, NULL);
   gGui->ao_none = xine_open_audio_driver(gGui->xine, "none", NULL);
 
@@ -2092,7 +2122,7 @@ int main(int argc, char *argv[]) {
     
     while(*plugin) {
       pplugin_parse_and_store_post((const char *) *plugin);
-      *plugin++;
+      plugin++;
     }
     
     pplugin_rewire_posts();
@@ -2120,5 +2150,5 @@ int main(int argc, char *argv[]) {
 
   free_command_line_args(&_argv, _argc);
 
-  return 0;
+  return retval;
 }
