@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: mediamark.h,v 1.18 2004/05/27 03:53:18 miguelfreitas Exp $
+ * $Id: mediamark.h,v 1.19 2004/07/21 19:56:16 f1rmb Exp $
  *
  */
 
@@ -87,6 +87,8 @@ int mrl_look_like_playlist(char *mrl);
 int mrl_look_like_file(char *mrl);
 void mediamark_collect_from_directory(char *filepathname);
 
+void mmk_editor_update_tips_timeout(unsigned long timeout);
+void mmk_editor_show_tips(int enabled, unsigned long timeout);
 void mmk_edit_mediamark(mediamark_t **mmk, apply_callback_t callback, void *data);
 int mmk_editor_is_visible(void);
 int mmk_editor_is_running(void);
