@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: menus.c,v 1.55 2004/07/02 21:41:03 f1rmb Exp $
+ * $Id: menus.c,v 1.58 2004/10/19 21:18:48 f1rmb Exp $
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -238,16 +238,14 @@ static void menu_playlist_from(xitk_widget_t *w, xitk_menu_entry_t *me, void *da
     /* Flush playlist in newbie mode */
     if(gGui->smart_mode) {
       mediamark_free_mediamarks();
-      gGui->playlist.cur = 0;
       playlist_update_playlist();
     }
     
-    if(!gGui->playlist.num)
-      gGui->playlist.cur = 0;
-    
     for (j = 0; j < num_mrls; j++)
       mediamark_append_entry(autoplay_mrls[j], autoplay_mrls[j], NULL, 0, -1, 0, 0);
     
+    gGui->playlist.cur = gGui->playlist.num ? 0 : -1;
+    
     if(gGui->playlist.cur == 0)
       gui_set_current_mmk(mediamark_get_current_mmk());
     
@@ -598,7 +596,7 @@ void video_window_menu(xitk_widget_list_t *wl) {
       NULL, NULL                                                                             },
     { _("Video/Deinterlace"),
       (sh[shc++] = menu_get_shortcut("ToggleInterleave")),
-      (xine_get_param(gGui->stream, XINE_PARAM_VO_DEINTERLACE)) ? "<checked>" : "<check>",
+      (gGui->deinterlace_enable) ? "<checked>" : "<check>",
       menu_video_ctrl, (void *) VIDEO_INTERLEAVE                                             },
     { _("Video/SEP"),
       NULL,
