@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 the xine project
+ * Copyright (C) 2000-2004 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: osd.h,v 1.10 2003/07/14 22:44:09 f1rmb Exp $
+ * $Id: osd.h,v 1.12 2004/11/15 21:43:20 f1rmb Exp $
  *
  */
 
@@ -26,6 +26,14 @@
 
 #include <stdarg.h>
 
+typedef struct {
+  xine_osd_t   *osd[2];
+  int           visible;
+  int           have_text;
+  int           x, y;
+  int           w, h;
+} osd_object_t;
+
 #define OSD_BAR_PROGRESS 1
 #define OSD_BAR_POS      2
 #define OSD_BAR_POS2     3
@@ -40,6 +48,11 @@ void osd_stream_infos(void);
 void osd_update_status(void);
 void osd_stream_position(int pos);
 void osd_display_info(char *info, ...);
-  /* see OSD_BAR_* */
+
+/* see OSD_BAR_* */
 void osd_draw_bar(char *title, int min, int max, int val, int type);
+
+int osd_is_visible(void);
+void osd_update_osd(void);
+
 #endif
