@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: playlist.c,v 1.154 2004/07/02 21:41:05 f1rmb Exp $
+ * $Id: playlist.c,v 1.159 2004/12/15 21:10:46 f1rmb Exp $
  *
  * Playlist Editor
  *
@@ -132,8 +132,8 @@ static void _playlist_free_playlists(void) {
       playlist->playlist_len--;
     }
     
-    free(playlist->playlist_mrls);
-    free(playlist->playlist_idents);
+    SAFE_FREE(playlist->playlist_mrls);
+    SAFE_FREE(playlist->playlist_idents);
     playlist->playlist_len = 0;
   }
 }
@@ -236,14 +236,17 @@ void playlist_delete_current(xitk_widget_t *w, void *data) {
     
     gGui->playlist.mmk[gGui->playlist.num] = NULL;
     
-    gGui->playlist.cur = 0;
     
     playlist_update_playlist();
     
-    if(gGui->playlist.num)
+    if(gGui->playlist.num) {
       gui_set_current_mmk(mediamark_get_current_mmk());
+      gGui->playlist.cur = 0;
+    }
     else {
       
+      gGui->playlist.cur = -1;
+
       if(is_playback_widgets_enabled())
 	enable_playback_controls(0);
       
@@ -614,6 +617,11 @@ void playlist_show_tips(int enabled, unsigned long timeout) {
   }
 }
 
+void playlist_update_tips_timeout(unsigned long timeout) {
+  if(playlist)
+    xitk_set_widgets_tips_timeout(playlist->widget_list, timeout);
+}
+
 void playlist_mrlident_toggle(void) {
 
   if(playlist && playlist->visible) {
@@ -716,7 +724,7 @@ int playlist_is_visible(void) {
     if(gGui->use_root_window)
       return xitk_is_window_visible(gGui->display, playlist->window);
     else
-      return playlist->visible;
+      return playlist->visible && xitk_is_window_visible(gGui->display, playlist->window);
   }
 
   return 0;
@@ -750,13 +758,8 @@ void playlist_scan_input(xitk_widget_t *w, void *ip) {
 	    playlist_update_playlist();
 	    if(playlist != NULL)
 	      xitk_inputtext_change_text(playlist->winput, NULL);
-	    gGui->playlist.cur = 0;
 	  }
 	  
-	  if(!gGui->playlist.num)
-	    gGui->playlist.cur = 0;
-	  
-
 	  stream = xine_stream_new(gGui->xine, gGui->ao_none, gGui->vo_none);
 	  
 	  for (j = 0; j < num_mrls; j++) {
@@ -775,6 +778,8 @@ void playlist_scan_input(xitk_widget_t *w, void *ip) {
 
 	  xine_dispose(stream);
 	  
+	  gGui->playlist.cur = gGui->playlist.num ? 0 : -1;
+	  
 	  if(gGui->playlist.cur == 0)
 	    gui_set_current_mmk(mediamark_get_current_mmk());
 	  
@@ -877,7 +882,7 @@ void playlist_update_focused_entry(void) {
 /*
  * Change the current skin.
  */
-void playlist_change_skins(void) {
+void playlist_change_skins(int synthetic) {
   ImlibImage   *new_img, *old_img;
   XSizeHints    hint;
 
