@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: post.c,v 1.53 2004/07/02 09:33:37 f1rmb Exp $
+ * $Id: post.c,v 1.55 2004/12/15 21:10:46 f1rmb Exp $
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -253,7 +253,7 @@ int post_rewire_audio_port_to_stream(xine_stream_t *stream) {
 
 int post_rewire_audio_post_to_stream(xine_stream_t *stream) {
   xine_post_out_t * audio_source;
-  
+
   audio_source = xine_get_audio_source(stream);
   return xine_post_wire_audio_port(audio_source, gGui->visual_anim.post_output->audio_input[0]);
 }
@@ -360,7 +360,7 @@ static int _pplugin_is_last_filter(post_object_t *pobj) {
     post_object_t **po = pplugin->post_objects;
     
     while(*po && (*po != pobj))
-      *po++;
+      po++;
     
     if(*(po + 1) == NULL)
       return 1;
@@ -1219,7 +1219,7 @@ static void _pplugin_move_up(xitk_widget_t *w, void *data) {
   _pplugin_unwire();
 
   while(*ppobj != pobj)
-    *ppobj++;
+    ppobj++;
   
   pobj_tmp = *--ppobj;
   *ppobj   = pobj;
@@ -1237,7 +1237,7 @@ static void _pplugin_move_down(xitk_widget_t *w, void *data) {
   _pplugin_unwire();
 
   while(*ppobj != pobj)
-    *ppobj++;
+    ppobj++;
   
   pobj_tmp = *(ppobj + 1);
   *ppobj   = pobj_tmp;
@@ -1374,7 +1374,7 @@ static void _pplugin_rebuild_filters(void) {
       _pplugin_retrieve_parameters(pplugin->post_objects[pplugin->object_num - 1]);
     }
     
-    *pelem++;
+    pelem++;
   }
   
   xitk_enable_widget(pplugin->new_filter);
@@ -1686,7 +1686,7 @@ int pplugin_is_visible(void) {
     if(gGui->use_root_window)
       return xitk_is_window_visible(gGui->display, xitk_window_get_window(pplugin->xwin));
     else
-      return pplugin->visible;
+      return pplugin->visible && xitk_is_window_visible(gGui->display, xitk_window_get_window(pplugin->xwin));
   }
   
   return 0;
