@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: videowin.c,v 1.203 2004/07/04 16:14:35 miguelfreitas Exp $
+ * $Id: videowin.c,v 1.211 2004/12/16 16:37:11 f1rmb Exp $
  *
  * video window handling functions
 */
@@ -59,9 +59,6 @@ extern gGui_t           *gGui;
 typedef struct {
   xitk_widget_list_t    *wl;
 
-  Cursor                 cursor[3];       /* Cursor pointers                       */
-  Pixmap                 pm_data[3];
-
   char                   window_title[1024];
   int                    current_cursor;  /* arrow or hand */
   int                    cursor_visible;
@@ -149,6 +146,7 @@ typedef struct {
   pthread_t              second_display_thread;
   int                    second_display_running;
   
+  int                    logo_synthetic;
 } gVw_t;
 
 static gVw_t            *gVw;
@@ -388,9 +386,11 @@ static void video_window_adapt_size (void) {
       if(gGui->video_display == gGui->display)
         xitk_widget_list_set(gVw->wl, WIDGET_LIST_WINDOW, (void *) gGui->video_window);
 
-      if(gGui->vo_port)
-	xine_port_send_gui_data(gGui->vo_port, 
-			      XINE_GUI_SEND_DRAWABLE_CHANGED, (void*)gGui->video_window);
+      if(gGui->vo_port) {
+        XUnlockDisplay (gGui->video_display);
+	xine_port_send_gui_data(gGui->vo_port, XINE_GUI_SEND_DRAWABLE_CHANGED, (void*)gGui->video_window);
+        XLockDisplay (gGui->video_display);
+      }
 
       XSelectInput(gGui->video_display, gGui->video_window, ExposureMask);
       
@@ -664,9 +664,11 @@ static void video_window_adapt_size (void) {
     if(gGui->video_display == gGui->display)
       xitk_widget_list_set(gVw->wl, WIDGET_LIST_WINDOW, (void *) gGui->video_window);
 
-    if(gGui->vo_port)
-      xine_port_send_gui_data(gGui->vo_port,
-			    XINE_GUI_SEND_DRAWABLE_CHANGED, (void*)gGui->video_window);
+    if(gGui->vo_port) {
+      XUnlockDisplay (gGui->video_display);
+      xine_port_send_gui_data(gGui->vo_port, XINE_GUI_SEND_DRAWABLE_CHANGED, (void*)gGui->video_window);
+      XLockDisplay (gGui->video_display);
+    }
 
     if (gVw->xclasshint_fullscreen != NULL)
       XSetClassHint(gGui->video_display, gGui->video_window, gVw->xclasshint_fullscreen);
@@ -759,9 +761,11 @@ static void video_window_adapt_size (void) {
     if(gGui->video_display == gGui->display)
       xitk_widget_list_set(gVw->wl, WIDGET_LIST_WINDOW, (void *) gGui->video_window);
     
-    if(gGui->vo_port)
-      xine_port_send_gui_data(gGui->vo_port,
-			    XINE_GUI_SEND_DRAWABLE_CHANGED, (void*)gGui->video_window);
+    if(gGui->vo_port) {
+      XUnlockDisplay (gGui->video_display);
+      xine_port_send_gui_data(gGui->vo_port, XINE_GUI_SEND_DRAWABLE_CHANGED, (void*)gGui->video_window);
+      XLockDisplay (gGui->video_display);
+    }
     
     if (gVw->xclasshint_fullscreen != NULL)
       XSetClassHint(gGui->video_display, gGui->video_window, gVw->xclasshint_fullscreen);
@@ -893,8 +897,11 @@ static void video_window_adapt_size (void) {
     if(gGui->video_display == gGui->display)
       xitk_widget_list_set(gVw->wl, WIDGET_LIST_WINDOW, (void *) gGui->video_window);
 
-    if(gGui->vo_port)
+    if(gGui->vo_port) {
+      XUnlockDisplay (gGui->video_display);
       xine_port_send_gui_data(gGui->vo_port, XINE_GUI_SEND_DRAWABLE_CHANGED, (void*)gGui->video_window);
+      XLockDisplay (gGui->video_display);
+    }
     
     if(gVw->borderless) {
       if (gVw->xclasshint_borderless != NULL)
@@ -1191,6 +1198,9 @@ void video_window_set_fullscreen_mode (int req_fullscreen) {
 
   video_window_adapt_size();
   try_to_set_input_focus(gGui->video_window);
+  if(osd_is_visible())
+    osd_update_osd();
+
 }
 
 /*
@@ -1229,14 +1239,20 @@ void video_window_set_cursor(int cursor) {
     
     if(gVw->cursor_visible) {
       gVw->cursor_timer = 0;
-      XLockDisplay (gGui->video_display);
-      XDefineCursor(gGui->video_display, gGui->video_window, 
-		    gVw->cursor[gVw->current_cursor]);
-      XSync(gGui->video_display, False);
-      XUnlockDisplay (gGui->video_display);
+      switch(gVw->current_cursor) {
+      case 0:
+	xitk_cursors_define_window_cursor(gGui->video_display, gGui->video_window, xitk_cursor_invisible);
+	break;
+      case CURSOR_ARROW:
+	xitk_cursors_restore_window_cursor(gGui->video_display, gGui->video_window);
+	break;
+      case CURSOR_HAND:
+	xitk_cursors_define_window_cursor(gGui->video_display, gGui->video_window, xitk_cursor_hand2);
+	break;
+      }
     }
   }
-
+  
 }
 
 /*
@@ -1251,12 +1267,16 @@ void video_window_set_cursor_visibility(int show_cursor) {
 
   if(show_cursor)
     gVw->cursor_timer = 0;
-
-  XLockDisplay (gGui->video_display);
-  XDefineCursor(gGui->video_display, gGui->video_window, 
-		gVw->cursor[show_cursor ? gVw->current_cursor : show_cursor]);
-  XSync(gGui->video_display, False);
-  XUnlockDisplay (gGui->video_display);
+  
+  if(show_cursor) {
+    if(gVw->current_cursor == CURSOR_ARROW)
+      xitk_cursors_restore_window_cursor(gGui->video_display, gGui->video_window);
+    else
+      xitk_cursors_define_window_cursor(gGui->video_display, gGui->video_window, xitk_cursor_hand1);
+  }
+  else
+    xitk_cursors_define_window_cursor(gGui->video_display, gGui->video_window, xitk_cursor_invisible);
+  
 }
 
 /* 
@@ -1305,6 +1325,13 @@ void video_window_set_visibility(int show_window) {
       xitk_set_layer_above(gGui->video_window);
     }
 
+    /* inform the window manager that we are fullscreen. This info musn't be set for xinerama-fullscreen,
+       otherwise there are 2 different window size for one fullscreen mode ! (kwin doesn't accept this) */
+    if( !(gVw->fullscreen_mode & WINDOWED_MODE)
+     && !(gVw->fullscreen_mode & FULLSCR_XI_MODE)
+     && wm_not_ewmh_only())
+      xitk_set_ewmh_fullscreen(gGui->video_window);
+    
   }
   else
     XUnmapWindow (gGui->video_display, gGui->video_window);
@@ -1344,40 +1371,7 @@ static int screen_is_in_xinerama_fullscreen_list (const char *list, int screen_n
 /*
  *
  */
-static unsigned char bm_no_data[] = { 
-  0,0,0,0, 0,0,0,0 
-};
-
-static unsigned char hand_bits[] = {
-  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00,
-  0x00, 0x48, 0x00, 0x00, 0x00, 0x48, 0x00, 0x00, 0x00, 0x48, 0x00, 0x00,
-  0x00, 0x48, 0x00, 0x00, 0x00, 0x48, 0x00, 0x00, 0x00, 0xc8, 0x01, 0x00,
-  0x00, 0x48, 0x0e, 0x00, 0x00, 0x48, 0x32, 0x00, 0x00, 0x4e, 0x52, 0x00,
-  0x00, 0x4b, 0x92, 0x00, 0x00, 0x09, 0x90, 0x00, 0x00, 0x09, 0x80, 0x00,
-  0x00, 0x09, 0x80, 0x00, 0x00, 0x01, 0x80, 0x00, 0x00, 0x01, 0x80, 0x00,
-  0x00, 0x01, 0x80, 0x00, 0x00, 0x02, 0x80, 0x00, 0x00, 0x02, 0xc0, 0x00,
-  0x00, 0x04, 0x40, 0x00, 0x00, 0x04, 0x60, 0x00, 0x00, 0xfc, 0x3f, 0x00,
-  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 
-};
-
-static unsigned char hand_mask_bits[] = {
-  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00,
-  0x00, 0x78, 0x00, 0x00, 0x00, 0x78, 0x00, 0x00, 0x00, 0x78, 0x00, 0x00,
-  0x00, 0x78, 0x00, 0x00, 0x00, 0x78, 0x00, 0x00, 0x00, 0xf8, 0x01, 0x00,
-  0x00, 0xf8, 0x0f, 0x00, 0x00, 0xf8, 0x3f, 0x00, 0x00, 0xfe, 0x7f, 0x00,
-  0x00, 0xff, 0xff, 0x00, 0x00, 0xff, 0xff, 0x00, 0x00, 0xff, 0xff, 0x00,
-  0x00, 0xff, 0xff, 0x00, 0x00, 0xff, 0xff, 0x00, 0x00, 0xff, 0xff, 0x00,
-  0x00, 0xff, 0xff, 0x00, 0x00, 0xfe, 0xff, 0x00, 0x00, 0xfe, 0xff, 0x00,
-  0x00, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0x3f, 0x00,
-  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 
-};
-
 void video_window_init (window_attributes_t *window_attribute, int hide_on_start) {
-  XColor                bg_curs, fg_curs;
   int                   i;
 #ifdef HAVE_XINERAMA
   int                   screens;
@@ -1601,30 +1595,8 @@ void video_window_init (window_attributes_t *window_attribute, int hide_on_start
     gVw->xclasshint_borderless->res_class = "xine";
   }
 
-  /* 
-   * create cursors
-   */
-  bg_curs.red   = 255 << 8;
-  bg_curs.green = 255 << 8;
-  bg_curs.blue  = 255 << 8;
-  fg_curs.red   = 0;
-  fg_curs.green = 0;
-  fg_curs.blue  = 0;
-  
-  gVw->pm_data[0]           = XCreateBitmapFromData(gGui->video_display,
-						    DefaultRootWindow(gGui->video_display), bm_no_data, 8, 8);
-  gVw->cursor[0]            = XCreatePixmapCursor(gGui->video_display, gVw->pm_data[0], gVw->pm_data[0],
-						  &gGui->black, &gGui->black, 0, 0);
-  gVw->cursor[CURSOR_ARROW] = XCreateFontCursor(gGui->video_display, XC_left_ptr);
-  
-  gVw->pm_data[1]           = XCreateBitmapFromData(gGui->display, 
-						    DefaultRootWindow(gGui->video_display), (char *)hand_bits, 32, 32);
-  gVw->pm_data[2]           = XCreateBitmapFromData(gGui->display, 
-						    DefaultRootWindow(gGui->video_display), (char *)hand_mask_bits, 32, 32);
-  gVw->cursor[CURSOR_HAND]  = XCreatePixmapCursor(gGui->display, gVw->pm_data[1], gVw->pm_data[2], &fg_curs, &bg_curs, 0, 0);
-  
-  gVw->current_cursor       = CURSOR_ARROW;
-  gVw->cursor_timer         = 0;
+  gVw->current_cursor = CURSOR_ARROW;
+  gVw->cursor_timer   = 0;
 
   /*
    * wm hints
@@ -1833,13 +1805,6 @@ void video_window_exit (void) {
   else
     pthread_join(gVw->second_display_thread, NULL);
 
-  XLockDisplay(gGui->display);
-  XFreeCursor(gGui->display, gVw->cursor[0]);
-  XFreeCursor(gGui->display, gVw->cursor[CURSOR_HAND]);
-  XFreePixmap(gGui->display, gVw->pm_data[0]);
-  XFreePixmap(gGui->display, gVw->pm_data[1]);
-  XFreePixmap(gGui->display, gVw->pm_data[2]);
-  XUnlockDisplay(gGui->display);
 }
 
 
@@ -1962,7 +1927,7 @@ void video_window_update_logo(void) {
      * Back to default logo only on a skin 
      * change, not at the first skin loading.
      **/
-    if((cfg_err_result) && (strcmp(cfg_entry.str_value, XINE_LOGO_MRL))) {
+    if(gVw->logo_synthetic && (cfg_err_result) && (strcmp(cfg_entry.str_value, XINE_LOGO_MRL))) {
       config_update_string("gui.logo_mrl", XINE_LOGO_MRL);
 
     __play_logo_now:
@@ -1990,7 +1955,8 @@ void video_window_update_logo(void) {
  __done:
   gGui->logo_has_changed--;
 }
-void video_window_change_skins(void) {
+void video_window_change_skins(int synthetic) {
+  gVw->logo_synthetic = (synthetic ? 1 : 0);
   gGui->logo_has_changed++;
 }
 
@@ -2039,8 +2005,10 @@ static void video_window_handle_event (XEvent *event, void *data) {
   break;
 
   case ButtonPress: {
-    XButtonEvent *bevent = (XButtonEvent *) event;
-    int x, y;
+    XButtonEvent       *bevent = (XButtonEvent *) event;
+    xine_input_data_t   input;
+    xine_event_t        event;
+    int                 x, y;
 
     if(!gGui->cursor_visible) {
       gGui->cursor_visible = !gGui->cursor_visible;
@@ -2057,22 +2025,9 @@ static void video_window_handle_event (XEvent *event, void *data) {
       
       timercpy(&gVw->click_time, &old_click_time);
       gettimeofday(&gVw->click_time, 0);
-      
-      if (video_window_translate_point(bevent->x, bevent->y, &x, &y)) {
-	xine_input_data_t input;
-	xine_event_t      event;
-	
-	event.type        = XINE_EVENT_INPUT_MOUSE_BUTTON;
-	event.stream      = gGui->stream;
-	event.data        = &input;
-	event.data_length = sizeof(input);
-	timercpy(&old_click_time, &event.tv);
-	input.button      = 1;
-	input.x           = x;
-	input.y           = y;
-	xine_event_send(gGui->stream, &event);
-      }
 
+      timercpy(&old_click_time, &event.tv);
+      
       timersub(&gVw->click_time, &old_click_time, &tm_diff);
       click_diff = (tm_diff.tv_sec * 1000) + (tm_diff.tv_usec / 1000.0);
       
@@ -2083,6 +2038,18 @@ static void video_window_handle_event (XEvent *event, void *data) {
       }
       
     }
+
+    if(video_window_translate_point(bevent->x, bevent->y, &x, &y)) {	
+      event.type        = XINE_EVENT_INPUT_MOUSE_BUTTON;
+      event.stream      = gGui->stream;
+      event.data        = &input;
+      event.data_length = sizeof(input);
+      input.button      = bevent->button;
+      input.x           = x;
+      input.y           = y;
+      xine_event_send(gGui->stream, &event);
+    }
+
   }
   break;
 
@@ -2105,8 +2072,11 @@ static void video_window_handle_event (XEvent *event, void *data) {
   case ConfigureNotify:
     if(event->xany.window == gGui->video_window) {
       XConfigureEvent *cev = (XConfigureEvent *) event;
-      Window tmp_win;
+      Window           tmp_win;
+      int              h, w;
 
+      h = gVw->output_height;
+      w = gVw->output_width;
       gVw->output_width  = cev->width;
       gVw->output_height = cev->height;
 
@@ -2120,6 +2090,10 @@ static void video_window_handle_event (XEvent *event, void *data) {
         gVw->xwin = cev->x;
         gVw->ywin = cev->y;
       }
+
+      if(osd_is_visible() && ((h != gVw->output_height) || (w != gVw->output_width)))
+	osd_update_osd();
+
     }
     break;
     
@@ -2192,3 +2166,32 @@ void video_window_set_mrl(char *mrl) {
     XUnlockDisplay(gGui->video_display);
   }
 }
+
+void video_window_toggle_border(void) {
+  
+  if(!gGui->use_root_window && (gVw->fullscreen_mode & WINDOWED_MODE)) {
+    Atom         prop;
+    MWMHints     mwmhints;
+    XClassHint  *xclasshint;
+    
+    gVw->borderless = !gVw->borderless;
+    
+    XLockDisplay(gGui->video_display);
+    
+    prop                 = XInternAtom(gGui->video_display, "_MOTIF_WM_HINTS", False);
+    mwmhints.flags       = MWM_HINTS_DECORATIONS;
+    mwmhints.decorations = gVw->borderless ? 0 : 1;
+    xclasshint           = gVw->borderless ? gVw->xclasshint_borderless : gVw->xclasshint;
+    
+    XChangeProperty(gGui->video_display, gGui->video_window, prop, prop, 32,
+		    PropModeReplace, (unsigned char *) &mwmhints,
+		    PROP_MWM_HINTS_ELEMENTS);
+    
+    if(xclasshint != NULL)
+      XSetClassHint(gGui->video_display, gGui->video_window, xclasshint);
+    
+    XUnlockDisplay (gGui->video_display);
+    
+    xine_port_send_gui_data(gGui->vo_port, XINE_GUI_SEND_DRAWABLE_CHANGED, (void *)gGui->video_window);
+  }
+}
