@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: videowin.h,v 1.38 2004/04/13 19:55:49 f1rmb Exp $
+ * $Id: videowin.h,v 1.40 2004/12/16 16:14:09 f1rmb Exp $
  *
  * video window handling functions
  */
@@ -81,7 +81,7 @@ void video_window_set_mag (float mag);
 float video_window_get_mag (void);
 
 void video_window_update_logo(void);
-void video_window_change_skins(void);
+void video_window_change_skins(int);
 
 void video_window_reset_ssaver(void);
 
@@ -92,4 +92,7 @@ void video_window_get_visible_size(int *w, int *h);
 void video_window_get_output_size(int *w, int *h);
 
 void video_window_set_mrl(char *mrl);
+
+void video_window_toggle_border(void);
+
 #endif
