@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: viewlog.c,v 1.50 2004/07/02 09:33:38 f1rmb Exp $
+ * $Id: viewlog.c,v 1.51 2004/12/15 21:10:46 f1rmb Exp $
  *
  *
  */
@@ -127,7 +127,7 @@ int viewlog_is_visible(void) {
     if(gGui->use_root_window)
       return xitk_is_window_visible(gGui->display, xitk_window_get_window(viewlog->xwin));
     else
-      return viewlog->visible;
+      return viewlog->visible && xitk_is_window_visible(gGui->display, xitk_window_get_window(viewlog->xwin));
   }
 
   return 0;
