@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2003 the xine project
+ * Copyright (C) 2000-2004 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: combo.c,v 1.36 2003/12/13 01:09:39 f1rmb Exp $
+ * $Id: combo.c,v 1.40 2004/07/21 19:56:17 f1rmb Exp $
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -154,7 +154,7 @@ static void combo_select(xitk_widget_t *w, void *data, int selected) {
     
     xitk_browser_release_all_buttons(private_data->browser_widget);
     xitk_browser_update_list(private_data->browser_widget, 
-			     (const char* const*)private_data->entries, 
+			     (const char* const*)private_data->entries, NULL,
 			     private_data->num_entries, 0);
     
     xitk_checkbox_set_state(private_data->button_widget, 0);
@@ -221,6 +221,18 @@ static void notify_change_skin(xitk_widget_t *w, xitk_skin_config_t *skonfig) {
   }
 }
 
+static void tips_timeout(xitk_widget_t *w, unsigned long timeout) {
+  if(w && (((w->type & WIDGET_GROUP_MASK) & WIDGET_GROUP_COMBO) &&
+	   (w->type & WIDGET_GROUP_WIDGET))) {
+    combo_private_data_t *private_data = (combo_private_data_t *) w->private_data;
+    
+    private_data->combo_widget->tips_timeout = timeout;
+    private_data->label_widget->tips_timeout = timeout;
+    private_data->button_widget->tips_timeout = timeout;
+    private_data->browser_widget->tips_timeout = timeout;
+  }
+}
+
 static int notify_event(xitk_widget_t *w, widget_event_t *event, widget_event_result_t *result) {
   int retval = 0;
   
@@ -237,6 +249,9 @@ static int notify_event(xitk_widget_t *w, widget_event_t *event, widget_event_re
   case WIDGET_EVENT_ENABLE:
     enability(w);
     break;
+  case WIDGET_EVENT_TIPS_TIMEOUT:
+    tips_timeout(w, event->tips_timeout);
+    break;
   }
   
   return retval;
@@ -486,7 +501,7 @@ void xitk_combo_update_list(xitk_widget_t *w, char **list, int len) {
     private_data->selected    = -1;
     
     xitk_browser_update_list(private_data->browser_widget, 
-			     (const char* const*)private_data->entries, 
+			     (const char* const*)private_data->entries, NULL,
 			     private_data->num_entries, 0);
   }
 }
@@ -614,7 +629,7 @@ static xitk_widget_t *_xitk_combo_create(xitk_widget_list_t *wl,
   private_data->browser_widget->type |= WIDGET_GROUP | WIDGET_GROUP_COMBO;
   
   xitk_browser_update_list(private_data->browser_widget, 
-			   (const char* const*)private_data->entries, 
+			   (const char* const*)private_data->entries, NULL,
 			   private_data->num_entries, 0);
   
   private_data->widget_key = 
@@ -689,8 +704,6 @@ xitk_widget_t *xitk_combo_create(xitk_widget_list_t *wl,
     *lw = private_data->label_widget;
   if(bw)
     *bw = private_data->button_widget;
-
-  
   
   {
     int x, y;
@@ -777,13 +790,13 @@ xitk_widget_t *xitk_noskin_combo_create(xitk_widget_list_t *wl,
     {
       xitk_image_t *wimage = xitk_get_widget_foreground_skin(private_data->label_widget);
       
-      if(wimage) {
+      if(wimage)
 	draw_rectangular_inner_box(c->imlibdata, wimage->image, 0, 0, wimage->width - 1, wimage->height - 1);
-      }
-      
+
       wimage = xitk_get_widget_foreground_skin(private_data->button_widget);
       
       if(wimage) {
+	draw_bevel_three_state(c->imlibdata, wimage);
 	draw_arrow_down(c->imlibdata, wimage);
       }
       
