@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: config.c,v 1.21 2004/06/19 02:13:45 komadori Exp $
+ * $Id: config.c,v 1.22 2004/07/26 00:43:47 f1rmb Exp $
  *
  */
 
@@ -181,6 +181,8 @@ static void xitk_config_features(xitk_config_t *xtcf) {
       else if(!strcasecmp(c, "check"))
 	xtcf->features.checkstyle = CHECK_STYLE_CHECK;
     }
+    else if(!strncasecmp(p, "cursors", 7))
+      xtcf->features.cursors = xitk_get_bool_value(c);
     else if(!strncasecmp(p, "shm", 3))
       xtcf->features.shm = strtol(c, &c, 10);
   }
@@ -335,6 +337,7 @@ static void xitk_config_init_default_values(xitk_config_t *xtcf) {
 #endif
   xtcf->features.oldbarstyle   = 0;
   xtcf->features.checkstyle    = CHECK_STYLE_CHECK;
+  xtcf->features.cursors       = 0;
   xtcf->menus.shortcuts        = 1;
 }
 
@@ -362,6 +365,13 @@ int xitk_config_get_shm_feature(xitk_config_t *xtcf) {
   
   return (xtcf->features.shm > 0) ? 1 : 0;
 }
+int xitk_config_get_cursors_feature(xitk_config_t *xtcf) {
+
+  if(!xtcf)
+    return -1;
+  
+  return (xtcf->features.cursors > 0) ? 1 : 0;
+}
 char *xitk_config_get_system_font(xitk_config_t *xtcf) {
 
   if(!xtcf)
