@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2003 the xine project
+ * Copyright (C) 2000-2004 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: dnd.c,v 1.21 2003/01/05 00:24:35 f1rmb Exp $
+ * $Id: dnd.c,v 1.24 2004/04/26 21:53:31 f1rmb Exp $
  *
  *
  * Thanks to Paul Sheer for his nice xdnd implementation in cooledit.
@@ -108,7 +108,7 @@ static int _dnd_paste_prop_internal(xitk_dnd_t *xdnd, Window from,
       char  buf[nread + 2];
       
       memset(&buf, '\0', sizeof(buf));
-      sprintf(buf, "%s", s);
+      snprintf(buf, sizeof(buf), "%s", s);
       
       if(strlen(buf)) {
 	char *p, *pbuf;
