@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2003 the xine project
+ * Copyright (C) 2000-2004 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: image.c,v 1.54 2003/12/14 14:10:33 f1rmb Exp $
+ * $Id: image.c,v 1.67 2004/12/16 21:35:30 f1rmb Exp $
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -27,9 +27,12 @@
 #include <stdio.h>
 #include <stdarg.h>
 #include <X11/Xlib.h>
+#include <errno.h>
 
 #include "_xitk.h"
 
+int xitk_x_error = 0;
+
 /*
  * Get a pixel color from rgb values.
  */
@@ -139,29 +142,35 @@ Pixmap xitk_image_create_pixmap(ImlibData *im, int width, int height) {
  *
  */
 static void xitk_image_xitk_pixmap_destroyer(xitk_pixmap_t *xpix) {
-
   ABORT_IF_NULL(xpix);
 
   XLOCK(xpix->imlibdata->x.disp);
-
-#ifdef HAVE_SHM
-  if(xpix->shm)
-    XShmDetach(xpix->imlibdata->x.disp, xpix->shminfo);
-
-  if(xpix->xim)
-    XDestroyImage(xpix->xim);
-
-  if(xpix->shm) {
-    shmdt(xpix->shminfo->shmaddr);
-    shmctl(xpix->shminfo->shmid, IPC_RMID, 0);
-    free(xpix->shminfo);
-  }
-#endif
   
   if(xpix->pixmap != None)
     XFreePixmap(xpix->imlibdata->x.disp, xpix->pixmap);
   
   XFreeGC(xpix->imlibdata->x.disp, xpix->gc);
+  XSync(xpix->imlibdata->x.disp, False);
+
+#ifdef HAVE_SHM
+  if(xpix->shm) {
+    XShmSegmentInfo *shminfo = xpix->shminfo;
+
+    XShmDetach(xpix->imlibdata->x.disp, shminfo);
+    
+    if(xpix->xim)
+      XDestroyImage(xpix->xim);
+    
+    if(shmdt(shminfo->shmaddr) < 0)
+      XITK_WARNING("shmdt() failed: '%s'\n", strerror(errno));
+
+    if(shmctl(shminfo->shmid, IPC_RMID, 0) < 0)
+      XITK_WARNING("shmctl() failed: '%s'\n", strerror(errno));
+    
+
+    free(shminfo);
+  }
+#endif
   
   XUNLOCK(xpix->imlibdata->x.disp);
   
@@ -171,18 +180,17 @@ static void xitk_image_xitk_pixmap_destroyer(xitk_pixmap_t *xpix) {
 /*
  *
  */
-xitk_pixmap_t *xitk_image_create_xitk_pixmap_with_depth(ImlibData *im, 
-							int width, int height, int depth) {
+xitk_pixmap_t *xitk_image_create_xitk_pixmap_with_depth(ImlibData *im, int width, int height, int depth) {
   xitk_pixmap_t    *xpix;
 #ifdef HAVE_SHM
   XShmSegmentInfo  *shminfo;
 #endif
-  
+
   ABORT_IF_NULL(im);
   ABORT_IF_NOT_COND(width > 0);
   ABORT_IF_NOT_COND(height > 0);
   
-  xpix = (xitk_pixmap_t *) xitk_xmalloc(sizeof(xitk_pixmap_t));
+  xpix            = (xitk_pixmap_t *) xitk_xmalloc(sizeof(xitk_pixmap_t));
   xpix->imlibdata = im;
   xpix->destroy   = xitk_image_xitk_pixmap_destroyer;
   xpix->width     = width;
@@ -242,10 +250,10 @@ xitk_pixmap_t *xitk_image_create_xitk_pixmap_with_depth(ImlibData *im,
       goto __noxshm_pixmap;
     }
 
-    xpix->xim = xim;
+    xpix->xim    = xim;
     xpix->pixmap = XShmCreatePixmap(im->x.disp, im->x.base_window, 
 				    shminfo->shmaddr, shminfo, width, height, depth);
-
+    
     if(!xpix->pixmap) {
       XITK_WARNING("XShmCreatePixmap() failed.\n");
       XShmDetach(xpix->imlibdata->x.disp, xpix->shminfo);
@@ -257,17 +265,10 @@ xitk_pixmap_t *xitk_image_create_xitk_pixmap_with_depth(ImlibData *im,
       goto __noxshm_pixmap;
     }
     else {
-      xpix->shm = 1;
-      //      XDestroyImage(xim);
-      xpix->shminfo = shminfo;
+      xpix->shm                    = 1;
+      xpix->shminfo                = shminfo;
       xpix->gcv.graphics_exposures = False;
-      xpix->gc = XCreateGC(im->x.disp, xpix->pixmap, GCGraphicsExposures, &xpix->gcv);
-      shmctl(shminfo->shmid, IPC_RMID, 0);
-
-      //      XShmPutImage(im->x.disp, xpix->pixmap, xpix->gc, xpix->xim, 
-      //		   0, 0, 0, 0, width, height, False);
-      //      XSync(im->x.disp, False);
-      
+      xpix->gc                     = XCreateGC(im->x.disp, xpix->pixmap, GCGraphicsExposures, &xpix->gcv);
       xitk_uninstall_x_error_handler();
     }
   }
@@ -303,6 +304,7 @@ void xitk_image_destroy_xitk_pixmap(xitk_pixmap_t *p) {
   p->destroy(p);
 }
 
+#if 0
 /*
  *
  */
@@ -319,6 +321,7 @@ Pixmap xitk_image_create_mask_pixmap(ImlibData *im, int width, int height) {
 
   return p;
 }
+#endif
 
 /*
  *
@@ -372,32 +375,33 @@ xitk_image_t *xitk_image_create_image(ImlibData *im, int width, int height) {
   ABORT_IF_NOT_COND(width > 0);
   ABORT_IF_NOT_COND(height > 0);
 
-  i = (xitk_image_t *) xitk_xmalloc(sizeof(xitk_image_t));
-  i->mask = NULL;
-  i->image = xitk_image_create_xitk_pixmap(im, width, height);
-  i->width = width;
+  i         = (xitk_image_t *) xitk_xmalloc(sizeof(xitk_image_t));
+  i->mask   = NULL;
+  i->image  = xitk_image_create_xitk_pixmap(im, width, height);
+  i->width  = width;
   i->height = height;
 
   return i;
 }
 
-
 /*
  *
  */
 xitk_image_t *xitk_image_create_image_with_colors_from_string(ImlibData *im, 
-							      char *fontname, 
-							      int width, int align, char *str,
-							      unsigned int foreground,
-							      unsigned int background) {
+                                                              char *fontname, 
+                                                              int width, int align, char *str,
+                                                              unsigned int foreground,
+                                                              unsigned int background) {
   xitk_image_t   *image;
   xitk_font_t    *fs;
   GC              gc;
-  int             length, height, descent;
-  char           *po, *p;
+  int             length, height, descent, linel, linew, wlinew, lastws;
+  int             maxw = 0;
+  const char     *p;
+  char           *bp;
   char           *lines[256];
   int             numlines = 0;
-  char            bufsubs[BUFSIZ], buf[BUFSIZ];
+  char            buf[BUFSIZ]; /* Could be allocated dynamically for bigger texts */
 
   ABORT_IF_NULL(im);
   ABORT_IF_NULL(fontname);
@@ -414,85 +418,118 @@ xitk_image_t *xitk_image_create_image_with_colors_from_string(ImlibData *im,
   height = xitk_font_get_string_height(fs, str);
   descent = xitk_font_get_descent(fs, str);
 
-  memset(&bufsubs, 0, sizeof(bufsubs));
-  memset(&buf, 0, sizeof(buf));
-  p = str;
+  p      = str;
+  bp     = buf;
+  wlinew = linew = lastws = linel = 0;
 
-  while(*p != '\0') {
+  while((*p!='\0') && (bp + linel) < (buf + BUFSIZ - TABULATION_SIZE - 2)) {
+    
     switch(*p) {
       
     case '\t':
-      sprintf(bufsubs, "%s%s", bufsubs, "      ");
+      {
+	int a;
+	
+	if((linel == 0) || (bp[linel - 1] != ' ')) {
+	  lastws = linel;
+	  wlinew = linew; /* width if wrapped */
+	}
+	
+	a = TABULATION_SIZE - (linel % TABULATION_SIZE);
+	
+        while(a--)
+          bp[linel++] = ' ';
+      }
       break;
-      
-    default:
-      sprintf(bufsubs, "%s%c", bufsubs, *p);
-      break;
-    }
-    p++;
-  }
 
-  po = p = &bufsubs[0];
-
-  while(*p != '\0') {
-
-    switch(*p) {
-      
-      /* Ignore */
-    case '\a':
-    case '\b':
-    case '\f':
-    case '\r':
-    case '\v':
-      break;
-      
+      case '\a':
+      case '\b':
+      case '\f':
+      case '\r':
+      case '\v':
+        break; /* Ignore those */
+	
     case '\n':
-      lines[numlines++] = strdup(buf);
-      po = p + 1;
-      memset(&buf, 0, sizeof(buf));
+      lines[numlines++] = bp;
+      bp                = bp + linel + 1;
+      
+      wlinew = lastws = linel = 0;
+      
+      if(linew > maxw)
+	maxw = linew;
       break;
+      
+    case ' ':
+      if((linel == 0) || (bp[linel-1] != ' ')) {
+	lastws = linel;
+	wlinew = linew; /* width if wrapped */
+      }
 
+      /* fall through */
     default:
-      sprintf(buf, "%s%c", buf, *p);
+      bp[linel++] = *p;
+
+      if(!lastws)
+	wlinew = linew;
       break;
     }
 
-    if(xitk_font_get_string_length(fs, buf) >= width) {
-      char buf2[BUFSIZ];
-      char *ps;
+    bp[linel] = '\0'; /* terminate the string for reading with xitk_font_get_string_length or strlen */
 
-      memset(&buf2, 0, sizeof(buf2));
-      /* step back */
-      if((ps = strrchr(buf, ' ')) != NULL) { /* Ok, there a space here */
-	ps = p;
-	while(*ps != ' ') ps--;
-	snprintf(buf2, (ps - po)+1, "%s", buf);
-	lines[numlines++] = strdup(buf2);
-	p = po = ps;
+    if((linew = xitk_font_get_string_length(fs, bp)) >= width) {
+      
+      if(lastws == 0) { /* if we haven't found a whitespace */
+        bp[linel]         = bp[linel-1]; /* Move that last character down */
+        bp[linel-1]       = 0;
+        lines[numlines++] = bp;
+        bp                += linel;
+        linel             = 1;
       }
-      else { /* cut to previous char */
-	snprintf(buf2, (p - po), "%s", buf);
-	sprintf(buf2, "%s%c", buf2, '-');
-	lines[numlines++] = strdup(buf2);
-	po = (p - 1);
-	p -= 2;
+      else {
+        char *nextword = (bp + lastws);
+        int   wordlen;
+	
+        while(*nextword == ' ')
+          nextword++;
+	
+        wordlen           = (bp + linel) - nextword;
+        bp[lastws]        = '\0';
+        lines[numlines++] = bp;
+        bp                = bp + lastws + 1;
+	
+        if(bp != nextword)
+          memmove(bp, nextword, wordlen + 1);
+	
+        linel = wordlen;
       }
-      memset(&buf, 0, sizeof(buf));
+      
+      if(wlinew > maxw)
+        maxw = wlinew;
+      
+      linew = xitk_font_get_string_length(fs, bp);
     }
-
+    
     p++;
   }
-
-  /* Last chars aren't stored */
-  if(strlen(buf))
-    lines[numlines++] = strdup(buf);
   
-  image = xitk_image_create_image(im, width, ((height * numlines) + (3 * numlines)));
+  if(linel) { /* In case last chars aren't stored */
+    lines[numlines++] = bp;
+    
+    if(linew > maxw)
+      maxw = linew;
+  }
+  
+  maxw += 10; /* add some space */
+  
+  if(align == ALIGN_LEFT) /* if it is left-aligned, we can resize the image */
+    width = MIN(maxw, width);
+  
+  image = xitk_image_create_image(im, width, (height + 3) * numlines);
   draw_flat_with_color(im, image->image, image->width, image->height, background);
   
   { /* Draw string in image */
     int i, j, x = 0;
-
+    
     XLOCK(im->x.disp);
     XSetForeground(im->x.disp, gc, foreground);
     XUNLOCK(im->x.disp);
@@ -502,18 +539,16 @@ xitk_image_t *xitk_image_create_image_with_colors_from_string(ImlibData *im,
       length = xitk_font_get_string_length(fs, lines[i]);
 
       if((align == ALIGN_DEFAULT) || (align == ALIGN_LEFT))
-	x = 0;
+        x = 0;
       else if(align == ALIGN_CENTER)
-	x = (width - length)>>1;
+        x = (maxw - length) >> 1;
       else if(align == ALIGN_RIGHT)
-	x = (width - length);
+        x = (maxw - length);
       
       XLOCK(im->x.disp);
       xitk_font_draw_string(fs, image->image->pixmap, gc, 
-		  x, (j - descent), lines[i], strlen(lines[i]));
+                            x, (j - descent), lines[i], strlen(lines[i]));
       XUNLOCK(im->x.disp);
-	
-      XITK_FREE(lines[i]);
     }
   }
 
@@ -528,7 +563,7 @@ xitk_image_t *xitk_image_create_image_with_colors_from_string(ImlibData *im,
 xitk_image_t *xitk_image_create_image_from_string(ImlibData *im, 
 						  char *fontname, 
 						  int width, int align, char *str) {
-  
+
   return xitk_image_create_image_with_colors_from_string(im,fontname, width, align, str,
 							 xitk_get_pixel_color_black(im),
 							 xitk_get_pixel_color_gray(im));
@@ -825,20 +860,125 @@ void draw_rectangular_outter_box_light(ImlibData *im, xitk_pixmap_t *p,
   _draw_rectangular_box_light(im, p, x, y, 0, 0, width, height, DRAW_OUTTER);
 }
 
+static void _draw_check_round(ImlibData *im, xitk_image_t *p, int x, int y, int d, int checked) {
+  XLOCK(im->x.disp);
+  XSetForeground(im->x.disp, p->image->gc, xitk_get_pixel_color_black(im));
+  XFillArc(im->x.disp, p->image->pixmap, p->image->gc, x, y, d, d, (30 * 64), (180 * 64));
+  XUNLOCK(im->x.disp);
+  
+  XLOCK(im->x.disp);
+  XSetForeground(im->x.disp, p->image->gc, xitk_get_pixel_color_darkgray(im));
+  XFillArc(im->x.disp, p->image->pixmap, p->image->gc, x, y, d, d, (210 * 64), (180 * 64));
+  XUNLOCK(im->x.disp);
+  
+  XLOCK(im->x.disp);
+  XSetForeground(im->x.disp, p->image->gc, xitk_get_pixel_color_white(im));
+  XFillArc(im->x.disp, p->image->pixmap, p->image->gc, x + 2, y + 2, d - 4, d - 4, (0 * 64), (360 * 64));
+  XUNLOCK(im->x.disp);
+  
+  if(checked) {
+    XLOCK(im->x.disp);
+    XSetForeground(im->x.disp, p->image->gc, xitk_get_pixel_color_black(im));
+    XFillArc(im->x.disp, p->image->pixmap, p->image->gc, x + 4, y + 4, d - 8, d - 8, (0 * 64), (360 * 64));
+    XUNLOCK(im->x.disp);
+  }
+}
+static void _draw_check_check(ImlibData *im, xitk_image_t *p, int x, int y, int d, int checked) {
+  /* background */
+  XLOCK(im->x.disp);
+  XSetForeground(im->x.disp, p->image->gc, xitk_get_pixel_color_lightgray(im));
+  XFillRectangle(im->x.disp, p->image->pixmap, p->image->gc, x, y, d, d);
+  XUNLOCK(im->x.disp);
+  /* */
+  XLOCK(im->x.disp);
+  XSetForeground(im->x.disp, p->image->gc, xitk_get_pixel_color_black(im));
+  XDrawLine(im->x.disp, p->image->pixmap, p->image->gc, x, y, x + d, y);
+  XDrawLine(im->x.disp, p->image->pixmap, p->image->gc, x, y, x, y + d);
+  XUNLOCK(im->x.disp);
+  
+  XLOCK(im->x.disp);
+  XSetForeground(im->x.disp, p->image->gc, xitk_get_pixel_color_darkgray(im));
+  XDrawLine(im->x.disp, p->image->pixmap, p->image->gc, x, y + d, x + d, y + d);
+  XDrawLine(im->x.disp, p->image->pixmap, p->image->gc, x + d, y, x + d, y + d);
+  XUNLOCK(im->x.disp);
+  
+  if(checked) {
+    XLOCK(im->x.disp);
+    XSetForeground(im->x.disp, p->image->gc, xitk_get_pixel_color_black(im));
+    XDrawLine(im->x.disp, p->image->pixmap, p->image->gc, x + (d / 5), (y + ((d / 3) * 2)) - 2, x + (d / 2), y + d - 2);
+    XDrawLine(im->x.disp, p->image->pixmap, p->image->gc, x + (d / 5)+1, (y + ((d / 3) * 2)) - 2, x + (d / 2) + 1, y + d - 2);
+    XDrawLine(im->x.disp, p->image->pixmap, p->image->gc, x + (d / 2), y + d - 2, x + d - 2, y+1);
+    XDrawLine(im->x.disp, p->image->pixmap, p->image->gc, x + (d / 2) + 1, y + d - 2, x + d - 1, y+1);
+    XUNLOCK(im->x.disp);
+  }
+  
+}
+
+static void draw_check_three_state_round_style(ImlibData *im, xitk_image_t *p, int x, int y, int d, int w, int checked) {
+  int i;
+
+  ABORT_IF_NULL(im);
+  ABORT_IF_NULL(p);
+
+  for(i = 0; i < 3; i++) {
+    if(i == 2) {
+      x++;
+      y++;
+    }
+
+    _draw_check_round(im, p, x, y, d, checked);
+    x += w;
+  }
+}
+
+static void draw_check_three_state_check_style(ImlibData *im, xitk_image_t *p, int x, int y, int d, int w, int checked) {
+  int i;
+
+  ABORT_IF_NULL(im);
+  ABORT_IF_NULL(p);
+  
+  for(i = 0; i < 3; i++) {
+    if(i == 2) {
+      x++;
+      y++;
+    }
+
+    _draw_check_check(im, p, x, y, d, checked);
+    x += w;
+  }
+}
+
 void menu_draw_check(ImlibData *im, xitk_image_t *p, int checked) {
-  int      h, w;
-  int      relief = (checked) ? DRAW_INNER : DRAW_OUTTER;
-  int      nrelief = (checked) ? DRAW_OUTTER : DRAW_INNER;
+  int  style = xitk_get_checkstyle_feature();
   
   ABORT_IF_NULL(im);
   ABORT_IF_NULL(p);
   
-  w = p->width / 3;
-  h = p->height - 12;
-  
-  _draw_rectangular_box(im, p->image, 4,               6,     0, 0, 12, h, relief);
-  _draw_rectangular_box(im, p->image, w + 4,           6,     0, 0, 12, h, relief);
-  _draw_rectangular_box(im, p->image, (w * 2) + 4 + 1, 6 + 1, 0, 0, 12, h, nrelief);
+  switch(style) {
+    
+  case CHECK_STYLE_CHECK:
+    draw_check_three_state_check_style(im, p, 4, 4, p->height - 8, p->width / 3, checked);
+    break;
+    
+  case CHECK_STYLE_ROUND:
+    draw_check_three_state_round_style(im, p, 4, 4, p->height - 8, p->width / 3, checked);
+    break;
+    
+  case CHECK_STYLE_OLD:
+  default: 
+    {
+      int      relief = (checked) ? DRAW_INNER : DRAW_OUTTER;
+      int      nrelief = (checked) ? DRAW_OUTTER : DRAW_INNER;
+      int      w, h;
+      
+      w = p->width / 3;
+      h = p->height - 12;
+      _draw_rectangular_box(im, p->image, 4,               6,     0, 0, 12, h, relief);
+      _draw_rectangular_box(im, p->image, w + 4,           6,     0, 0, 12, h, relief);
+      _draw_rectangular_box(im, p->image, (w * 2) + 4 + 1, 6 + 1, 0, 0, 12, h, nrelief);
+    }
+    break;
+  }
 }
 
 /*
@@ -975,6 +1115,45 @@ static void _draw_relief(ImlibData *im, xitk_pixmap_t *p, int w, int h, int reli
 
 }
 
+void draw_checkbox_check(ImlibData *im, xitk_image_t *p) {
+  int  style = xitk_get_checkstyle_feature();
+  
+  XLOCK(im->x.disp);
+  XSetForeground(im->x.disp, p->image->gc, xitk_get_pixel_color_gray(im));
+  XFillRectangle(im->x.disp, p->image->pixmap, p->image->gc, 0, 0, p->width, p->height);
+  XUNLOCK(im->x.disp);
+  
+  switch(style) {
+    
+  case CHECK_STYLE_CHECK:
+    {
+      int w;
+      
+      w = p->width / 3;
+      _draw_check_check(im, p, 0, 0, p->height, 0);
+      _draw_check_check(im, p, w, 0, p->height, 0);
+      _draw_check_check(im, p, w * 2, 0, p->height, 1);
+    }
+    break;
+    
+  case CHECK_STYLE_ROUND:
+    {
+      int w;
+      
+      w = p->width / 3;
+      _draw_check_round(im, p, 0, 0, p->height, 0);
+      _draw_check_round(im, p, w, 0, p->height, 0);
+      _draw_check_round(im, p, w * 2, 0, p->height, 1);
+    }
+    break;
+    
+  case CHECK_STYLE_OLD:
+  default: 
+    _draw_three_state(im, p, STYLE_BEVEL);
+    break;
+  }
+}
+
 /*
  *
  */
@@ -1404,7 +1583,9 @@ xitk_image_t *xitk_image_load_image(ImlibData *im, char *image) {
   
   XLOCK(im->x.disp);
   if(!(img = Imlib_load_image(im, (char *)image))) {
-    XITK_DIE("%s(): couldn't find image %s\n", __FUNCTION__, image);
+    XITK_WARNING("%s(): couldn't find image %s\n", __FUNCTION__, image);
+    XUNLOCK(im->x.disp);
+    return NULL;
   }
   
   Imlib_render (im, img, img->rgb_width, img->rgb_height);
@@ -1415,11 +1596,16 @@ xitk_image_t *xitk_image_load_image(ImlibData *im, char *image) {
   i->image->pixmap = Imlib_copy_image(im, img);
   XUNLOCK(im->x.disp);
 
-  i->mask          = xitk_image_create_xitk_mask_pixmap(im, img->rgb_width, img->rgb_height);
-  XLOCK(im->x.disp);
-  i->mask->pixmap  = Imlib_copy_mask(im, img);
-  XUNLOCK(im->x.disp);
-
+  if(img->shape_mask) {
+    i->mask          = xitk_image_create_xitk_mask_pixmap(im, img->rgb_width, img->rgb_height);
+    XLOCK(im->x.disp);
+    i->mask->pixmap  = Imlib_copy_mask(im, img);
+    XUNLOCK(im->x.disp);
+  }
+  else {
+    i->mask = NULL;
+  }
+    
   i->width         = img->rgb_width;
   i->height        = img->rgb_height;
   
@@ -1444,8 +1630,11 @@ static void notify_destroy(xitk_widget_t *w) {
   
   if(w && ((w->type & WIDGET_TYPE_MASK) == WIDGET_TYPE_IMAGE)) {
     private_data = (image_private_data_t *) w->private_data;
+
+    if(!private_data->skin_element_name)
+      xitk_image_free_image(private_data->imlibdata, &(private_data->skin));
+
     XITK_FREE(private_data->skin_element_name);
-    xitk_image_free_image(private_data->imlibdata, &private_data->skin);
     XITK_FREE(private_data);
   }
 }
@@ -1521,9 +1710,8 @@ static void notify_change_skin(xitk_widget_t *w, xitk_skin_config_t *skonfig) {
       
       xitk_skin_lock(skonfig);
 
-      xitk_image_free_image(private_data->imlibdata, &private_data->skin);
-      private_data->skin = xitk_image_load_image(private_data->imlibdata,
-						 xitk_skin_get_skin_filename(skonfig, private_data->skin_element_name));
+      private_data->skin = xitk_skin_get_image(skonfig,
+					       xitk_skin_get_skin_filename(skonfig, private_data->skin_element_name));
       
       w->x               = xitk_skin_get_coord_x(skonfig, private_data->skin_element_name);
       w->y               = xitk_skin_get_coord_y(skonfig, private_data->skin_element_name);
@@ -1617,9 +1805,8 @@ xitk_widget_t *xitk_image_create (xitk_widget_list_t *wl,
 			    (xitk_skin_get_coord_x(skonfig, im->skin_element_name)),
 			    (xitk_skin_get_coord_y(skonfig, im->skin_element_name)),
 			    im->skin_element_name,
-			    (xitk_image_load_image(im->imlibdata,
-						   xitk_skin_get_skin_filename(skonfig, 
-								       im->skin_element_name))));
+			    (xitk_skin_get_image(skonfig,
+						 xitk_skin_get_skin_filename(skonfig, im->skin_element_name))));
 }
 
 /*
