@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2003 the xine project
+ * Copyright (C) 2000-2004 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: image.h,v 1.22 2003/01/05 00:24:35 f1rmb Exp $
+ * $Id: image.h,v 1.26 2004/07/02 13:23:31 f1rmb Exp $
  *
  */
 
@@ -38,6 +38,7 @@
 #define ALIGN_RIGHT   3
 #define ALIGN_DEFAULT (ALIGN_LEFT)
 
+#define TABULATION_SIZE 6 /* number of chars inserted in place of a tabulation */
 
 typedef struct {
   ImlibData            *imlibdata;
@@ -47,3 +48,5 @@ typedef struct {
 } image_private_data_t;
 
 #endif
+
+void draw_checkbox_check(ImlibData *im, xitk_image_t *p);
