@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: inputtext.c,v 1.65 2004/06/13 11:44:18 f1rmb Exp $
+ * $Id: inputtext.c,v 1.68 2004/12/15 08:15:56 pmhahn Exp $
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -31,7 +31,6 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/keysym.h>
-#include <X11/cursorfont.h>
 
 #include "_xitk.h"
 
@@ -48,15 +47,10 @@ static void _cursor_focus(inputtext_private_data_t *private_data, Window win, in
 
   private_data->cursor_focus = focus;
   
-  XLOCK(private_data->imlibdata->x.disp);
-
   if(focus)
-    XDefineCursor(private_data->imlibdata->x.disp, win, private_data->cursor[1]);
+    xitk_cursors_define_window_cursor(private_data->imlibdata->x.disp, win, xitk_cursor_xterm);
   else
-    XDefineCursor(private_data->imlibdata->x.disp, win, private_data->cursor[0]);
-  
-  XSync(private_data->imlibdata->x.disp, False);
-  XUNLOCK(private_data->imlibdata->x.disp);
+    xitk_cursors_restore_window_cursor(private_data->imlibdata->x.disp, win);
 }
 
 /*
@@ -68,11 +62,6 @@ static void notify_destroy(xitk_widget_t *w) {
   if(w && ((w->type & WIDGET_TYPE_MASK) == WIDGET_TYPE_INPUTTEXT)) {
     private_data = (inputtext_private_data_t *) w->private_data;
   
-    XLOCK(private_data->imlibdata->x.disp);
-    XFreeCursor(private_data->imlibdata->x.disp, private_data->cursor[0]);
-    XFreeCursor(private_data->imlibdata->x.disp, private_data->cursor[1]);
-    XUNLOCK(private_data->imlibdata->x.disp);
-
     if(!private_data->skin_element_name)
       xitk_image_free_image(private_data->imlibdata, &(private_data->skin));
     
@@ -163,13 +152,13 @@ int xitk_get_key_modifier(XEvent *xev, int *modifier) {
   return (*modifier != MODIFIER_NOMOD);
 }
 
-int xitk_get_keysym_and_buf(XEvent *event, KeySym *ksym, char kbuf[]) {
+int xitk_get_keysym_and_buf(XEvent *event, KeySym *ksym, char kbuf[], int kblen) {
   int len = 0;
   if(event) {
     XKeyEvent  pkeyev = event->xkey;
     
     XLOCK(pkeyev.display);
-    len = XLookupString(&pkeyev, kbuf, sizeof(kbuf), ksym, NULL);
+    len = XLookupString(&pkeyev, kbuf, kblen, ksym, NULL);
     XUNLOCK(pkeyev.display);
   }
   return len;
@@ -183,7 +172,7 @@ KeySym xitk_get_key_pressed(XEvent *event) {
   
   if(event) {
     char  buf[256];
-    (void) xitk_get_keysym_and_buf(event, &pkey, buf);
+    (void) xitk_get_keysym_and_buf(event, &pkey, buf, sizeof(buf));
   }
 
   return pkey;
@@ -403,7 +392,12 @@ static void create_labelofinputtext(xitk_widget_t *w,
     
     width = (label && strlen(label)) ? 
       xitk_font_get_text_width(fs, plabel, (private_data->cursor_pos - private_data->disp_offset)) : 0;
-  
+
+#ifdef WITH_XFT
+    if(width)
+      width += 2;
+#endif
+    
     XLOCK(private_data->imlibdata->x.disp);
     XDrawLine(private_data->imlibdata->x.disp, pix, gc,
 	      width + 1, 2, width + 3, 2);
@@ -874,7 +868,7 @@ static void notify_keyevent_inputtext(xitk_widget_t *w, XEvent *xev) {
 
     private_data->have_focus = FOCUS_RECEIVED;
 
-    len = xitk_get_keysym_and_buf(xev, &key, buf);
+    len = xitk_get_keysym_and_buf(xev, &key, buf, sizeof(buf));
     buf[len] = '\0';
 
     (void) xitk_get_key_modifier(xev, &modifier);
@@ -1161,10 +1155,6 @@ static xitk_widget_t *_xitk_inputtext_create (xitk_widget_list_t *wl,
 
   private_data->disp_offset       = 0;
 
-  XLOCK(private_data->imlibdata->x.disp);
-  private_data->cursor[0] = XCreateFontCursor(private_data->imlibdata->x.disp, XC_left_ptr);
-  private_data->cursor[1] = XCreateFontCursor(private_data->imlibdata->x.disp, XC_xterm);
-  XUNLOCK(private_data->imlibdata->x.disp);
   private_data->cursor_focus      = 0;
 
   private_data->callback          = it->callback;
