@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2002 the xine project
+ * Copyright (C) 2000-2004 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -17,16 +17,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: labelbutton.h,v 1.13 2002/07/17 20:29:31 f1rmb Exp $
+ * $Id: labelbutton.h,v 1.22 2004/04/13 19:55:50 f1rmb Exp $
  *
  */
 
 #ifndef HAVE_XITK_LABELBUTTON_H
 #define HAVE_XITK_LABELBUTTON_H
 
-#include <X11/Xlib.h>
-#include "Imlib-light/Imlib.h"
-#include "widget.h"
 #include "_xitk.h"
 
 #define CLICK_BUTTON 1
@@ -45,7 +42,7 @@ typedef struct {
 
   int                     bState;
   int                     bOldState;
-  xitk_image_t            *skin;
+  xitk_image_t           *skin;
 
   xitk_simple_callback_t  callback;
   xitk_state_callback_t   state_callback;
@@ -53,6 +50,7 @@ typedef struct {
   void                   *userdata;
    
   int                     align;
+  int                     label_offset;
   int                     label_visible;
   int                     label_static;
 
@@ -61,50 +59,12 @@ typedef struct {
   char                   *focuscolor;
   char                   *clickcolor;
   char                   *fontname;
+  
+  /* Only used if (w->type & WIDGET_GROUP_MASK) == WIDGET_GROUP_BROWSER || WIDGET_GROUP_MENU */
+  char                   *shortcut_label;
+  char                   *shortcut_font;
+  int                     shortcut_pos;
 
 } lbutton_private_data_t;
 
-/* ***************************************************************** */
-
-xitk_widget_t *xitk_noskin_labelbutton_create (xitk_widget_list_t *wl,
-					       xitk_labelbutton_widget_t *b,
-					       int x, int y, int width, int height,
-					       char *ncolor, char *fcolor, char *ccolor, 
-					       char *fname);
-/**
-  * Create a labeled button.
-  */
-xitk_widget_t *xitk_labelbutton_create (xitk_widget_list_t *wl,
-					xitk_skin_config_t *skonfig, xitk_labelbutton_widget_t *b);
-
-/**
- * Change label of button 'widget'.
- */
-int xitk_labelbutton_change_label(xitk_widget_list_t *wl, xitk_widget_t *, char *);
-
-/**
- * Return label of button 'widget'.
- */
-char *xitk_labelbutton_get_label(xitk_widget_t *);
-
-/**
- * Get state of button 'widget'.
- */
-int xitk_labelbutton_get_state(xitk_widget_t *);
-
-/**
- * Set state of button "widget'.
- */
-void xitk_labelbutton_set_state(xitk_widget_t *, int, Window, GC);
-
-/**
- * Set label button alignment
- */
-void xitk_labelbutton_set_alignment(xitk_widget_t *, int);
-
-/**
- * Get label button alignment
- */
-int xitk_labelbutton_get_alignment(xitk_widget_t *);
-
 #endif
