@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2003 the xine project
+ * Copyright (C) 2000-2004 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: menu.c,v 1.16 2003/11/22 12:25:48 valtri Exp $
+ * $Id: menu.c,v 1.23 2004/04/26 21:53:34 f1rmb Exp $
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -90,6 +90,7 @@ static xitk_menu_entry_t *_menu_build_menu_entry(xitk_menu_entry_t *me, char *na
 
   mentry            = (xitk_menu_entry_t *) xitk_xmalloc(sizeof(xitk_menu_entry_t));
   mentry->menu      = strdup((name) ? buffer : me->menu);
+  mentry->shortcut  = (me->shortcut) ? strdup(me->shortcut) : NULL;
   mentry->type      = (me->type) ? strdup(me->type) : NULL;
   mentry->cb        = me->cb;
   mentry->user_data = me->user_data;
@@ -144,6 +145,24 @@ static int _menu_is_title(xitk_menu_entry_t *me) {
     return 1;
   return 0;
 }
+static int _menu_branch_have_check(menu_node_t *branch) {
+  while(branch) {
+    if(_menu_is_check(branch->menu_entry) || _menu_is_checked(branch->menu_entry))
+      return 1;
+    
+    branch = branch->next;
+  }
+  return 0;
+}
+static int _menu_branch_have_branch(menu_node_t *branch) {
+  while(branch) {
+    if(_menu_is_branch(branch->menu_entry))
+      return 1;
+    
+    branch = branch->next;
+  }
+  return 0;
+}
 
 #ifdef DUMP_MENU
 #ifdef	__GNUC__
@@ -260,17 +279,46 @@ static menu_node_t *_menu_get_wider_menuitem_node(menu_node_t *branch) {
   menu_node_t  *max = NULL;
   int           len = 0;
   
-  
   while(me) {
     if((!_menu_is_separator(me->menu_entry)) && 
-       (me->menu_entry->menu && (strlen(me->menu_entry->menu) > len))) {
+       (me->menu_entry->menu && 
+	((strlen(me->menu_entry->menu) > len)))) {
       len = strlen(me->menu_entry->menu);
       max = me;
     }
     
     me = me->next;
   }
+
+  return max;
+}
+static int _menu_branch_have_shortcut(menu_node_t *branch) {
+  menu_node_t  *me = branch;
   
+  while(me) {
+    if((!_menu_is_separator(me->menu_entry)) && me->menu_entry->shortcut)
+      return 1;
+    me = me->next;
+  }
+  
+  return 0;
+}
+static menu_node_t *_menu_get_wider_shortcut_node(menu_node_t *branch) {
+  menu_node_t  *me = branch;
+  menu_node_t  *max = NULL;
+  int           len = 0;
+  
+  while(me) {
+    if((!_menu_is_separator(me->menu_entry)) && 
+       (me->menu_entry->shortcut && 
+	((strlen(me->menu_entry->shortcut) > len)))) {
+      len = strlen(me->menu_entry->shortcut);
+      max = me;
+    }
+    
+    me = me->next;
+  }
+
   return max;
 }
 
@@ -324,6 +372,8 @@ static void _menu_destroy_ntree(menu_node_t **mn) {
   if((*mn)->menu_entry) {
     if((*mn)->menu_entry->menu)
       free((*mn)->menu_entry->menu);
+    if((*mn)->menu_entry->shortcut)
+      free((*mn)->menu_entry->shortcut);
     if((*mn)->menu_entry->type)
       free((*mn)->menu_entry->type);
     free((*mn)->menu_entry);
@@ -517,7 +567,7 @@ void xitk_menu_add_entry(xitk_widget_t *w, xitk_menu_entry_t *me) {
       menu_node_t         *branch = NULL;
       int                  in_trunk = 1;
 
-      sprintf(buffer, "%s", me->menu);
+      snprintf(buffer, sizeof(buffer), "%s", me->menu);
       
       o = c = new_entry = buffer;
 
@@ -620,7 +670,7 @@ static void _menu_create_menu_from_branch(menu_node_t *branch, xitk_widget_t *w,
   menu_private_data_t        *private_data;
   int                         bentries, bsep, btitle, rentries;
   menu_node_t                *maxnode, *me;
-  int                         maxlen, wwidth, wheight, swidth, sheight;
+  int                         maxlen, wwidth, wheight, swidth, sheight, shortcutlen = 0, shortcutpos = 0;
   xitk_font_t                *fs;
   static xitk_window_t       *xwin;
   menu_window_t              *menu_window;
@@ -648,10 +698,24 @@ static void _menu_create_menu_from_branch(menu_node_t *branch, xitk_widget_t *w,
 
   xitk_font_set_font(fs, private_data->widget->wl->gc);
   maxlen = xitk_font_get_string_length(fs, maxnode->menu_entry->menu);
+
+  if(xitk_get_menu_shortcuts_enability() && _menu_branch_have_shortcut(branch)) {
+    xitk_font_t *short_font;
+    short_font = xitk_font_load_font(private_data->imlibdata->x.disp, DEFAULT_FONT_12);
+    shortcutlen = xitk_font_get_string_length(short_font, (_menu_get_wider_shortcut_node(branch))->menu_entry->shortcut);
+    maxlen += shortcutlen + 15;
+    xitk_font_unload_font(short_font);
+  }
+
   xitk_font_unload_font(fs);
-  
+
   wwidth = maxlen + 40;
+
+  if(_menu_branch_have_check(branch) || _menu_branch_have_branch(branch))
+    wwidth += 20;
   wheight = (rentries * 20) + (bsep * 2) + (btitle * 2);
+
+  shortcutpos = (wwidth - shortcutlen) - 15;
   
   XLOCK(private_data->imlibdata->x.disp);
   swidth = DisplayWidth(private_data->imlibdata->x.disp, 
@@ -667,7 +731,8 @@ static void _menu_create_menu_from_branch(menu_node_t *branch, xitk_widget_t *w,
   
   xwin = xitk_window_create_simple_window(private_data->imlibdata, 
 					  x, y, wwidth + 2, wheight + 2);
-  
+  xitk_set_wm_window_type(xitk_window_get_window(xwin), WINDOW_TYPE_DOCK);
+
   if(bsep || btitle) {
     int width, height;
     
@@ -722,9 +787,9 @@ static void _menu_create_menu_from_branch(menu_node_t *branch, xitk_widget_t *w,
 		       1, 1, wwidth , 20);
 	XSetForeground(private_data->imlibdata->x.disp, private_data->widget->wl->gc, cfg);
 	xitk_font_draw_string(fs, bg->pixmap, 
-		    private_data->widget->wl->gc, 
-		    5, 1+ ((20+asc+des)>>1)-des, 
-		    me->menu_entry->menu, strlen(me->menu_entry->menu));
+			      private_data->widget->wl->gc, 
+			      5, 1+ ((20+asc+des)>>1)-des, 
+			      me->menu_entry->menu, strlen(me->menu_entry->menu));
 	XUNLOCK(private_data->imlibdata->x.disp);
 	
 	xitk_font_unload_font(fs);
@@ -759,7 +824,10 @@ static void _menu_create_menu_from_branch(menu_node_t *branch, xitk_widget_t *w,
 								     DEFAULT_BOLD_FONT_12)));
       btn->type |= WIDGET_GROUP | WIDGET_GROUP_MENU;
       me->button = btn;
-
+      
+      if(xitk_get_menu_shortcuts_enability()  && me->menu_entry->shortcut)
+	xitk_labelbutton_change_shortcut_label(btn, me->menu_entry->shortcut, shortcutpos, DEFAULT_FONT_12);
+      
       wimage = xitk_get_widget_foreground_skin(btn);
       if(wimage) {
 	draw_flat_three_state(private_data->imlibdata, wimage);				
