@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: mrlbrowser.c,v 1.83 2004/04/26 21:53:34 f1rmb Exp $
+ * $Id: mrlbrowser.c,v 1.84 2004/09/14 20:40:31 f1rmb Exp $
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -190,7 +190,6 @@ static void mrlbrowser_filter_mrls(mrlbrowser_private_data_t *private_data) {
   if(private_data->filter_selected) {
     char *filter_ends;
     char *p, *m;
-    char *ending;
 
     private_data->mc->mrls_to_disp = 0;
 
@@ -208,9 +207,9 @@ static void mrlbrowser_filter_mrls(mrlbrowser_private_data_t *private_data) {
 	private_data->mc->mrls_to_disp++;
       }
       else {
-	ending = strrchr(private_data->mc->mrls[i]->mrl, '.');
-	
-	if(ending) {
+	char *ending;
+
+	if((ending = strrchr(private_data->mc->mrls[i]->mrl, '.'))) {
 
 	  while((m = xitk_strsep(&filter_ends, ",")) != NULL) {
 	    
