@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: skin.c,v 1.37 2004/07/02 13:23:31 f1rmb Exp $
+ * $Id: skin.c,v 1.38 2004/11/22 08:45:26 f1rmb Exp $
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -108,7 +108,7 @@ static void skin_free_cache(xitk_skin_config_t *skonfig) {
  *
  */
 #warning FIXME
-static char *_get_expanded_command(xitk_skin_config_t *skonfig, char *cmd) {
+static char *_expanded(xitk_skin_config_t *skonfig, char *cmd) {
   char *p;
   char *ret = NULL;
   char  buf[BUFSIZ], buf2[BUFSIZ], var[BUFSIZ];
@@ -620,11 +620,11 @@ static void skin_parse_section(xitk_skin_config_t *skonfig) {
 	  skin_set_pos_to_value(&p);
 
 	  if(!strncasecmp(section, "unload_command", 14)) {
-	    skonfig->unload_command = _get_expanded_command(skonfig, p);
+	    skonfig->unload_command = _expanded(skonfig, p);
 	    return;
 	  }
 	  else if(!strncasecmp(section, "load_command", 12)) {
-	    skonfig->load_command = _get_expanded_command(skonfig, p);
+	    skonfig->load_command = _expanded(skonfig, p);
 	    return;
 	  }
 	  else if(!strncasecmp(section, "animation", 9)) {
@@ -648,7 +648,7 @@ static void skin_parse_section(xitk_skin_config_t *skonfig) {
 	    return;
 	  }
 	  else if(!strncasecmp(section, "logo", 4)) {
-	    skonfig->logo = strdup(p);
+	    skonfig->logo = _expanded(skonfig, p);
 	    return;
 	  }
 	  else if(!strncasecmp(section, "url", 3)) {
