@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: tips.c,v 1.32 2004/07/02 13:23:31 f1rmb Exp $
+ * $Id: tips.c,v 1.36 2004/12/17 20:03:52 f1rmb Exp $
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -29,6 +29,7 @@
 #include <pthread.h>
 #include <inttypes.h>
 #include <unistd.h>
+#include <sys/time.h>
 
 #include <X11/Xlib.h>
 
@@ -38,20 +39,17 @@ typedef struct {
   Display             *display;
   pthread_t            thread;
 
-  xitk_widget_t       *widget;
+  xitk_widget_t       *widget, *new_widget;
   int                  visible;
   int                  running;
 
   pthread_mutex_t      mutex;
   
-  pthread_mutex_t      new_mutex;
   pthread_cond_t       new_cond;
   
-  pthread_mutex_t      timer_mutex;
   pthread_cond_t       timer_cond;
 
   int                  prewait;
-  pthread_mutex_t      prewait_mutex;
   pthread_cond_t       prewait_cond;
 } _tips_t;
 
@@ -59,7 +57,6 @@ static _tips_t tips;
 
 static void _tips_handle_event(XEvent *event, void *data) {
   switch(event->type) {
-  case MotionNotify:
   case ButtonRelease:
   case ButtonPress:
     xitk_tips_hide_tips();
@@ -71,34 +68,37 @@ static void *_tips_loop_thread(void *data) {
 
   tips.running = 1;
   
+  pthread_mutex_lock(&tips.mutex);
+
   while(tips.running) {
     struct timeval       tv;
     struct timespec      ts;
-    int                  result = 1;
 
-    pthread_mutex_lock(&tips.new_mutex);
-    pthread_cond_wait(&tips.new_cond, &tips.new_mutex);
-    pthread_mutex_unlock(&tips.new_mutex);
-    
-    pthread_mutex_lock(&tips.prewait_mutex);
+    /* Wait for a new tip to show */
+    if(!tips.new_widget)
+      pthread_cond_wait(&tips.new_cond, &tips.mutex);
+
+    /* Start over if nothing */
+    if(!tips.new_widget)
+      continue;
     
     tips.prewait = 1;
     
     gettimeofday(&tv, NULL);
-    ts.tv_sec  = tv.tv_sec;
-    ts.tv_nsec = (tv.tv_usec + 300000) * 1000;      
+    ts.tv_sec  = tv.tv_sec + (tv.tv_usec + 500000) / 1000000;
+    ts.tv_nsec = ((tv.tv_usec + 500000) % 1000000) * 1000;
     
-    result = pthread_cond_timedwait(&tips.prewait_cond, &tips.prewait_mutex, &ts);
-    tips.prewait = 0;
+    pthread_cond_timedwait(&tips.prewait_cond, &tips.mutex, &ts);
     
-    if(!result) {
-      tips.widget = NULL;
-      pthread_mutex_unlock(&tips.prewait_mutex);
+    /* Start over if interrupted */
+    if(!tips.prewait)
       continue;
-    }
-    
-    pthread_mutex_unlock(&tips.prewait_mutex);
 
+    tips.prewait = 0;
+
+    tips.widget = tips.new_widget;
+    tips.new_widget = NULL;
+    
     if(tips.widget && (tips.widget->tips_timeout > 0) && tips.widget->tips_string && strlen(tips.widget->tips_string)) {
       int                  x, y, string_length;
       xitk_window_t       *xwin;
@@ -202,15 +202,15 @@ static void *_tips_loop_thread(void *data) {
 					_tips_handle_event,
 					NULL,
 					NULL,
-					NULL,
+					tips.widget->wl,
 					NULL);
-            
-      gettimeofday(&tv, NULL);
-      ts.tv_sec  = tv.tv_sec;
-      ts.tv_nsec = (tv.tv_usec + (tips.widget->tips_timeout * 10000)) * 1000;      
 
-      pthread_mutex_lock(&tips.timer_mutex);
-      pthread_cond_timedwait(&tips.timer_cond, &tips.timer_mutex, &ts);
+      gettimeofday(&tv, NULL);
+      /* We round to ms instead of us (tips_timeout is ms anyway) to get out most of an int */
+      ts.tv_sec  = tv.tv_sec + ((tv.tv_usec + 500) / 1000 + tips.widget->tips_timeout) / 1000;
+      ts.tv_nsec = (((tv.tv_usec + 500) / 1000 + tips.widget->tips_timeout) % 1000) * 1000000;
+      
+      pthread_cond_timedwait(&tips.timer_cond, &tips.mutex, &ts);
 
       xitk_unregister_event_handler(&key);
       xitk_window_destroy_window(tips.widget->imlibdata, xwin);
@@ -220,15 +220,13 @@ static void *_tips_loop_thread(void *data) {
       XSync(tips.display, False);
       XUNLOCK(tips.display);
 
-      tips.widget = NULL;
-      
       tips.visible = 0;
-
-      pthread_mutex_unlock(&tips.timer_mutex);
     }
 
   }
 
+  pthread_mutex_unlock(&tips.mutex);
+
   pthread_exit(NULL);
 }
 
@@ -239,26 +237,25 @@ void xitk_tips_init(Display *disp) {
   
   if(!tips.running) {
     pthread_attr_t       pth_attrs;
-#if ! defined (__OpenBSD__)
+#ifdef _POSIX_THREAD_PRIORITY_SCHEDULING
     struct sched_param   pth_params;
 #endif
 
-    tips.visible = 0;
-    tips.display = disp;
-    tips.widget  = NULL;
-    tips.prewait = 0;
+    tips.visible    = 0;
+    tips.display    = disp;
+    tips.widget     = NULL;
+    tips.new_widget = NULL;
+    tips.prewait    = 0;
 
     pthread_mutex_init(&tips.mutex, NULL);
-    pthread_mutex_init(&tips.new_mutex, NULL);
-    pthread_mutex_init(&tips.timer_mutex, NULL);
-    pthread_mutex_init(&tips.prewait_mutex, NULL);
 
     pthread_cond_init(&tips.new_cond, NULL);
     pthread_cond_init(&tips.timer_cond, NULL);
     pthread_cond_init(&tips.prewait_cond, NULL);
     
     pthread_attr_init(&pth_attrs);
-#if ! defined (__OpenBSD__)
+
+#ifdef _POSIX_THREAD_PRIORITY_SCHEDULING
     pthread_attr_getschedparam(&pth_attrs, &pth_params);
     pth_params.sched_priority = sched_get_priority_min(SCHED_OTHER);
     pthread_attr_setschedparam(&pth_attrs, &pth_params);
@@ -275,24 +272,20 @@ void xitk_tips_deinit(void) {
   tips.running = 0;
   
   pthread_mutex_lock(&tips.mutex);
-  if(tips.prewait)
+  tips.new_widget = NULL;
+  if(tips.prewait) {
+    tips.prewait = 0;
     pthread_cond_signal(&tips.prewait_cond);
+  }
   else if(tips.visible)
     pthread_cond_signal(&tips.timer_cond);
   else
     pthread_cond_signal(&tips.new_cond);
-  
-  pthread_mutex_lock(&tips.timer_mutex);
+  pthread_mutex_unlock(&tips.mutex);
 
   pthread_join(tips.thread, NULL);
 
-  pthread_mutex_unlock(&tips.mutex);
-  pthread_mutex_unlock(&tips.timer_mutex);
-
   pthread_mutex_destroy(&tips.mutex);
-  pthread_mutex_destroy(&tips.new_mutex);
-  pthread_mutex_destroy(&tips.timer_mutex);
-  pthread_mutex_destroy(&tips.prewait_mutex);
   
   pthread_cond_destroy(&tips.new_cond);
   pthread_cond_destroy(&tips.timer_cond);
@@ -305,7 +298,12 @@ void xitk_tips_deinit(void) {
 void xitk_tips_hide_tips(void) {
   pthread_mutex_lock(&tips.mutex);
   if(tips.running) {
-    if(tips.widget && tips.visible)
+    tips.new_widget = NULL;
+    if(tips.prewait) {
+      tips.prewait = 0;
+      pthread_cond_signal(&tips.prewait_cond);
+    }
+    else if(tips.visible)
       pthread_cond_signal(&tips.timer_cond);
   }
   pthread_mutex_unlock(&tips.mutex);
@@ -317,13 +315,14 @@ void xitk_tips_hide_tips(void) {
 void xitk_tips_show_widget_tips(xitk_widget_t *w) {
   pthread_mutex_lock(&tips.mutex);
   if(tips.running) {
-    
-    if(tips.prewait)
+    tips.new_widget = w;
+    if(tips.prewait) {
+      tips.prewait = 0;
       pthread_cond_signal(&tips.prewait_cond);
-    else if(tips.widget && tips.visible)
+    }
+    else if(tips.visible)
       pthread_cond_signal(&tips.timer_cond);
-    
-    if((tips.widget != w) && (tips.widget = w))
+    else
       pthread_cond_signal(&tips.new_cond);
   }
   pthread_mutex_unlock(&tips.mutex);
@@ -338,6 +337,13 @@ void xitk_tips_set_timeout(xitk_widget_t *w, unsigned long timeout) {
     return;
   
   w->tips_timeout = timeout;
+  if(w->type & (WIDGET_GROUP | WIDGET_GROUP_WIDGET)) {
+    widget_event_t  event;
+    
+    event.type         = WIDGET_EVENT_TIPS_TIMEOUT;
+    event.tips_timeout = timeout;
+    (void) w->event(w, &event, NULL);
+  }
 }
 
 /*
@@ -372,6 +378,6 @@ void xitk_tips_set_tips(xitk_widget_t *w, char *str) {
   
   /* No timeout, set it to default */
   if(!w->tips_timeout)
-    xitk_tips_set_timeout(w, TIPS_TIMEOUT);
+    xitk_tips_set_timeout(w, xitk_get_tips_timeout());
 
 }
