@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2002 the xine project
+ * Copyright (C) 2000-2004 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: tips.h,v 1.2 2002/03/21 00:22:53 f1rmb Exp $
+ * $Id: tips.h,v 1.7 2004/06/17 22:13:56 f1rmb Exp $
  *
  */
 
@@ -26,8 +26,11 @@
 
 #define TIPS_TIMEOUT 500
 
-void xitk_tips_create(xitk_widget_t *w, xitk_widget_list_t *wl);
-void xitk_tips_tips_kill(xitk_widget_t *w);
+void xitk_tips_init(Display *display);
+void xitk_tips_deinit(void);
+void xitk_tips_show_widget_tips(xitk_widget_t *w);
+void xitk_tips_hide_tips(void);
+
 void xitk_tips_set_timeout(xitk_widget_t *w, unsigned long timeout);
 void xitk_tips_set_tips(xitk_widget_t *w, char *str);
 
