@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: xitk.c,v 1.128 2004/07/02 13:23:31 f1rmb Exp $
+ * $Id: xitk.c,v 1.132 2004/12/15 21:10:48 f1rmb Exp $
  *
  */
 #define _XITK_C_
@@ -84,6 +84,10 @@ static int ml = 0;
 #define MUTUNLOCK() { pthread_mutex_unlock(&gXitk->mutex); }
 #endif
 
+#define FXLOCK(_fx) { pthread_mutex_lock(&_fx->mutex); }
+#define FXUNLOCK(_fx) { pthread_mutex_unlock(&_fx->mutex); }
+
+
 typedef struct {
   Window                      window;
   Atom                        XA_XITK;
@@ -112,10 +116,14 @@ typedef struct {
   xitk_register_key_t         key;
   xitk_dnd_t                 *xdnd;
   void                       *user_data;
+
+  pthread_mutex_t             mutex;
+  int                         destroy;
 } __gfx_t;
 
 typedef struct {
   Display                    *display;
+  XColor                      black;
   int                         display_width;
   int                         display_height;
   int                         verbosity;
@@ -140,6 +148,7 @@ typedef struct {
   struct timeval              keypress;
 
   pthread_t                  *tips_thread;
+  unsigned long               tips_timeout;
 } __xitk_t;
 
 static __xitk_t    *gXitk;
@@ -931,14 +940,14 @@ void xitk_set_wm_window_type(Window window, xitk_wm_window_type_t type) {
 xitk_widget_list_t *xitk_widget_list_new (void) {
   xitk_widget_list_t *l;
 
-  MUTLOCK();
-
   l = (xitk_widget_list_t *) xitk_xmalloc(sizeof(xitk_widget_list_t));
 
   l->widget_focused     = NULL;
   l->widget_under_mouse = NULL;
   l->widget_pressed     = NULL;
 
+  MUTLOCK();
+
   xitk_list_append_content(gXitk->list, l);
 
   MUTUNLOCK();
@@ -960,6 +969,7 @@ void xitk_change_window_for_event_handler (xitk_register_key_t key, Window windo
   
   while(fx) {
 
+    FXLOCK(fx);
     if(fx->key == key) {
 
       fx->window = window;
@@ -969,9 +979,12 @@ void xitk_change_window_for_event_handler (xitk_register_key_t key, Window windo
 	  xitk_unset_dnd_callback(fx->xdnd);
       }
       
+      FXUNLOCK(fx);
       MUTUNLOCK();
       return;
     }
+    
+    FXUNLOCK(fx);
     fx = (__gfx_t *) xitk_list_next_content(gXitk->gfx);
   }
 
@@ -1011,6 +1024,7 @@ xitk_register_key_t xitk_register_event_handler(char *name, Window window,
   fx->width     = 0;
   fx->height    = 0;
   fx->user_data = user_data;
+  pthread_mutex_init(&fx->mutex, NULL);
   
   if(window != None) {
     XWindowAttributes wattr;
@@ -1088,6 +1102,65 @@ xitk_register_key_t xitk_register_event_handler(char *name, Window window,
   return fx->key;
 }
 
+static void __fx_destroy(__gfx_t *fx, int locked) {
+  __gfx_t *cur;
+  
+  if(!fx)
+    return;
+  
+  if(!locked)
+    MUTLOCK();
+  
+  cur = (__gfx_t *) xitk_list_get_current(gXitk->gfx);
+  
+  if(fx->xdnd) {
+    xitk_unset_dnd_callback(fx->xdnd);
+    free(fx->xdnd);
+  }
+  
+  fx->xevent_callback = NULL;
+  fx->newpos_callback = NULL;
+  fx->user_data       = NULL;
+
+  free(fx->name);
+  
+  if(cur) {
+    if(cur == fx)
+      xitk_list_delete_current(gXitk->gfx); 
+    else {
+      __gfx_t *cfx;
+      
+      cfx = (__gfx_t *) xitk_list_first_content(gXitk->gfx);
+      while(cfx) {
+	if(cfx == fx) {
+	  xitk_list_delete_current(gXitk->gfx); 
+	  break;
+	}
+	
+	cfx = (__gfx_t *) xitk_list_next_content(gXitk->gfx);
+      }
+      
+      /* set current back */
+      cfx = (__gfx_t *) xitk_list_first_content(gXitk->gfx);
+      while(cfx) {
+	
+	if(cfx == cur)
+	  break;
+	
+	cfx = (__gfx_t *) xitk_list_next_content(gXitk->gfx);
+      }
+    }
+  }
+  
+  FXUNLOCK(fx);
+  pthread_mutex_destroy(&fx->mutex);
+
+  free(fx);
+  
+  if(!locked)
+    MUTUNLOCK();
+}
+
 /*
  * Remove from the list the window/event_handler
  * specified by the key.
@@ -1102,28 +1175,27 @@ void xitk_unregister_event_handler(xitk_register_key_t *key) {
   fx = (__gfx_t *) xitk_list_first_content(gXitk->gfx);
   
   while(fx) {
-    
-    if(fx->key == *key) {
-      *key = 0; 
-      
-      if(fx->xdnd) {
-	xitk_unset_dnd_callback(fx->xdnd);
-	free(fx->xdnd);
+
+    if(pthread_mutex_trylock(&fx->mutex)) {
+      if(fx->key == *key) {
+	*key        = 0; 
+	fx->destroy = 1;
+	MUTUNLOCK();
+	return;
       }
-
-      fx->xevent_callback = NULL;
-      fx->newpos_callback = NULL;
-      fx->user_data       = NULL;
-
-      xitk_list_delete_current(gXitk->gfx); 
-
-      free(fx->name);
-      free(fx);
-      fx = NULL;
-      
-      MUTUNLOCK();
-      return;
     }
+    else {
+      if(fx->key == *key) {
+	*key = 0; 
+	
+	__fx_destroy(fx, 1);
+	fx = NULL;
+	MUTUNLOCK();
+	return;
+      }
+    }
+
+    FXUNLOCK(fx);
 
     fx = (__gfx_t *) xitk_list_next_content(gXitk->gfx);
   }
@@ -1136,13 +1208,17 @@ void xitk_unregister_event_handler(xitk_register_key_t *key) {
  */
 int xitk_get_window_info(xitk_register_key_t key, window_info_t *winf) {
   __gfx_t  *fx;
-  
+
   MUTLOCK();
 
   fx = (__gfx_t *) xitk_list_first_content(gXitk->gfx);
     
   while(fx) {
+    int  already_locked = 0;
     
+    if(pthread_mutex_trylock(&fx->mutex))
+      already_locked = 1;
+
     if((fx->key == key) && (fx->window != None)) {
       Window c;
       
@@ -1162,12 +1238,18 @@ int xitk_get_window_info(xitk_register_key_t key, window_info_t *winf) {
       winf->height = fx->height;
       winf->width  = fx->width;
       
+      if(!already_locked)
+	FXUNLOCK(fx);
+
       MUTUNLOCK();
       return 1;
 
     }
+    
+    if(!already_locked)
+      FXUNLOCK(fx);
+    
     fx = (__gfx_t *) xitk_list_next_content(gXitk->gfx);
-
   }
 
   MUTUNLOCK();
@@ -1180,9 +1262,12 @@ int xitk_get_window_info(xitk_register_key_t key, window_info_t *winf) {
  */
 void xitk_xevent_notify(XEvent *event) {
   __gfx_t  *fx;
-    
-  fx = (__gfx_t *) xitk_list_first_content(gXitk->gfx);
-
+     
+  if(!(fx = (__gfx_t *) xitk_list_first_content(gXitk->gfx)))
+    return;
+  
+  FXLOCK(fx);
+  
   if(gXitk->modalw != None) {
     while(fx && (fx->window != gXitk->modalw)) {
       
@@ -1251,6 +1336,7 @@ void xitk_xevent_notify(XEvent *event) {
 	      xitk_set_focus_to_next_widget(fx->widget_list, 0);
 	    }
 
+	    FXUNLOCK(fx);
 	    return;
 	  }
 	  
@@ -1260,6 +1346,7 @@ void xitk_xevent_notify(XEvent *event) {
 	      xitk_widget_t *m = xitk_menu_get_menu(w);
 	      
 	      xitk_menu_destroy(m);
+	      FXUNLOCK(fx);
 	      return;
 	    }
 	  }
@@ -1327,7 +1414,7 @@ void xitk_xevent_notify(XEvent *event) {
 	    }
 	    else if(w && (((w->type & WIDGET_TYPE_MASK) == WIDGET_TYPE_SLIDER) 
 			  && (w->type & WIDGET_KEYABLE))) {
-	      if((mykey == XK_Left) || (mykey == XK_Down)) {
+	      if((mykey == XK_Left) || (mykey == XK_Down) || (mykey == XK_Next)) {
 		handled = 1;
 		xitk_slider_make_backstep(w);
 		xitk_slider_callback_exec(w);
@@ -1396,6 +1483,14 @@ void xitk_xevent_notify(XEvent *event) {
 	      
 	    }
 	  }
+	  
+	  if(fx->destroy) {
+	    __fx_destroy(fx, 0);
+	    fx = NULL;
+	  }
+	  else
+	    FXUNLOCK(fx);
+
 	  return;
 	}
 	break;
@@ -1460,8 +1555,20 @@ void xitk_xevent_notify(XEvent *event) {
 	    }
 	  }
 	}
-	break;
-	
+	  break;
+	  
+	case LeaveNotify:
+	  if(fx->widget_list)
+	    xitk_motion_notify_widget_list (fx->widget_list,
+					    event->xmotion.x,
+					    event->xmotion.y, event->xmotion.state);
+	  break;
+	  
+	case FocusOut:
+	  if(fx->widget_list)
+	    xitk_motion_notify_widget_list (fx->widget_list, -1, -1, 0);
+	  break;
+	  
 	case ButtonPress: {
 	  XWindowAttributes   wattr;
 	  Status              status;
@@ -1610,30 +1717,48 @@ void xitk_xevent_notify(XEvent *event) {
       /* Don't forward event to all of windows */
       if(fx->xevent_callback && (fx->window != None && event->type != KeyRelease))
 	fx->xevent_callback(event, fx->user_data);
-
+      
     }
-
+    
+    if(fx->destroy) {
+      __fx_destroy(fx, 0);
+      fx = NULL;
+    }
+    else
+      FXUNLOCK(fx);
+    
+#warning FIXME
     if(gXitk->modalw != None) {
       fx = (__gfx_t *) xitk_list_next_content(gXitk->gfx);
 
       /* Flush remain fxs */
       while(fx && (fx->window != gXitk->modalw)) {
+	FXLOCK(fx);
+	
 	if(fx->xevent_callback && (fx->window != None && event->type != KeyRelease))
 	  fx->xevent_callback(event, fx->user_data);
-
+	
+	if(fx->destroy) {
+	  __fx_destroy(fx, 0);
+	  fx = NULL;
+	}
+	else
+	  FXUNLOCK(fx);
+	
 	fx = (__gfx_t *) xitk_list_next_content(gXitk->gfx);
       }
       return;
     }
-    
-    fx = (__gfx_t *) xitk_list_next_content(gXitk->gfx);
+
+    if((fx = (__gfx_t *) xitk_list_next_content(gXitk->gfx)))
+      FXLOCK(fx);
   }
 }
 
 /*
  * Initiatization of widget internals.
  */
-void xitk_init(Display *display, int verbosity) {
+void xitk_init(Display *display, XColor black, int verbosity) {
   char buffer[256];
   
   xitk_pid = getppid();
@@ -1644,6 +1769,7 @@ void xitk_init(Display *display, int verbosity) {
 
   gXitk = (__xitk_t *) xitk_xmalloc(sizeof(__xitk_t));
 
+  gXitk->black           = black;
   gXitk->display_width   = DisplayWidth(display, DefaultScreen(display));
   gXitk->display_height  = DisplayHeight(display, DefaultScreen(display));
   gXitk->verbosity       = verbosity;
@@ -1658,6 +1784,7 @@ void xitk_init(Display *display, int verbosity) {
   xitk_x_error           = 0;
   gXitk->x_error_handler = NULL;
   gXitk->modalw          = None;
+  gXitk->tips_timeout    = TIPS_TIMEOUT;
 
   memset(&gXitk->keypress, 0, sizeof(gXitk->keypress));
 
@@ -1731,7 +1858,8 @@ void xitk_init(Display *display, int verbosity) {
   
   /* init font caching */
   xitk_font_cache_init();
-
+  
+  xitk_cursors_init(display);
   xitk_tips_init(display);
 }
 
@@ -1811,7 +1939,8 @@ void xitk_run(xitk_startup_callback_t cb, void *data) {
   fx = (__gfx_t *) xitk_list_first_content(gXitk->gfx);
   
   while(fx) {
-    
+    FXLOCK(fx);
+   
     if(fx->window != None && fx->widget_list) {
       XEvent xexp;
       
@@ -1828,6 +1957,8 @@ void xitk_run(xitk_startup_callback_t cb, void *data) {
       }
       XUNLOCK(gXitk->display);
     }
+
+    FXUNLOCK(fx);
     fx = (__gfx_t *) xitk_list_next_content(gXitk->gfx);
   }
 
@@ -1885,6 +2016,7 @@ void xitk_run(xitk_startup_callback_t cb, void *data) {
  */
 void xitk_stop(void) {
   xitk_tips_deinit();
+  xitk_cursors_deinit(gXitk->display);
   gXitk->running = 0;
 }
  
@@ -1933,6 +2065,10 @@ int xitk_get_barstyle_feature(void) {
 int xitk_get_checkstyle_feature(void) {
   return xitk_config_get_checkstyle_feature(gXitk->config);
 }
+int xitk_get_cursors_feature(void) {
+  return xitk_config_get_cursors_feature(gXitk->config);
+}
+
 int xitk_get_menu_shortcuts_enability(void) {
   return xitk_config_get_menu_shortcuts_enability(gXitk->config);
 }
@@ -1943,6 +2079,16 @@ int xitk_get_display_width(void) {
 int xitk_get_display_height(void) {
   return gXitk->display_height;
 }
+XColor xitk_get_black_pixel_color(void) {
+  return gXitk->black;
+}
+
+unsigned long xitk_get_tips_timeout(void) {
+  return gXitk->tips_timeout;
+}
+void xitk_set_tips_timeout(unsigned long timeout) {
+  gXitk->tips_timeout = timeout;
+}
 
 /*
  * copy src to dest and substitute special chars. dest should have 
