@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: xitk.h,v 1.130 2004/07/02 22:26:35 f1rmb Exp $
+ * $Id: xitk.h,v 1.136 2004/12/16 21:35:30 f1rmb Exp $
  *
  * Unique public header file for xitk TK.
  *
@@ -75,6 +75,7 @@
 #define INPUT_MOTION                (ExposureMask | ButtonPressMask | ButtonReleaseMask | \
                                      KeyPressMask | KeyReleaseMask | ButtonMotionMask |   \
                                      StructureNotifyMask | PropertyChangeMask |           \
+                                     FocusChangeMask |			                  \
                                      LeaveWindowMask | EnterWindowMask | PointerMotionMask)
 
 #define WINDOW_INFO_ZERO(w)         do {                  \
@@ -332,6 +333,88 @@ typedef enum {
 void xitk_set_wm_window_type(Window window, xitk_wm_window_type_t type);
 void xitk_unset_wm_window_type(Window window, xitk_wm_window_type_t type);
 
+typedef enum {
+  xitk_cursor_invisible,
+  xitk_cursor_X_cursor,
+  xitk_cursor_arrow,
+  xitk_cursor_based_arrow_down,
+  xitk_cursor_based_arrow_up,
+  xitk_cursor_boat,
+  xitk_cursor_bogosity,
+  xitk_cursor_bottom_left_corner,
+  xitk_cursor_bottom_right_corner,
+  xitk_cursor_bottom_side,
+  xitk_cursor_bottom_tee,
+  xitk_cursor_box_spiral,
+  xitk_cursor_center_ptr,
+  xitk_cursor_circle,
+  xitk_cursor_clock,
+  xitk_cursor_coffee_mug,
+  xitk_cursor_cross,
+  xitk_cursor_cross_reverse,
+  xitk_cursor_crosshair,
+  xitk_cursor_diamond_cross,
+  xitk_cursor_dot,
+  xitk_cursor_dotbox,
+  xitk_cursor_double_arrow,
+  xitk_cursor_draft_large,
+  xitk_cursor_draft_small,
+  xitk_cursor_draped_box,
+  xitk_cursor_exchange,
+  xitk_cursor_fleur,
+  xitk_cursor_gobbler,
+  xitk_cursor_gumby,
+  xitk_cursor_hand1,
+  xitk_cursor_hand2,
+  xitk_cursor_heart,
+  xitk_cursor_icon,
+  xitk_cursor_iron_cross,
+  xitk_cursor_left_ptr,
+  xitk_cursor_left_side,
+  xitk_cursor_left_tee,
+  xitk_cursor_leftbutton,
+  xitk_cursor_ll_angle,
+  xitk_cursor_lr_angle,
+  xitk_cursor_man,
+  xitk_cursor_middlebutton,
+  xitk_cursor_mouse,
+  xitk_cursor_pencil,
+  xitk_cursor_pirate,
+  xitk_cursor_plus,
+  xitk_cursor_question_arrow,
+  xitk_cursor_right_ptr,
+  xitk_cursor_right_side,
+  xitk_cursor_right_tee,
+  xitk_cursor_rightbutton,
+  xitk_cursor_rtl_logo,
+  xitk_cursor_sailboat,
+  xitk_cursor_sb_down_arrow,
+  xitk_cursor_sb_h_double_arrow,
+  xitk_cursor_sb_left_arrow,
+  xitk_cursor_sb_right_arrow,
+  xitk_cursor_sb_up_arrow,
+  xitk_cursor_sb_v_double_arrow,
+  xitk_cursor_shuttle,
+  xitk_cursor_sizing,
+  xitk_cursor_spider,
+  xitk_cursor_spraycan,
+  xitk_cursor_star,
+  xitk_cursor_target,
+  xitk_cursor_tcross,
+  xitk_cursor_top_left_arrow,
+  xitk_cursor_top_left_corner,
+  xitk_cursor_top_right_corner,
+  xitk_cursor_top_side,
+  xitk_cursor_top_tee,
+  xitk_cursor_trek,
+  xitk_cursor_ul_angle,
+  xitk_cursor_umbrella,
+  xitk_cursor_ur_angle,
+  xitk_cursor_watch,
+  xitk_cursor_xterm,
+  xitk_cursor_num_glyphs
+} xitk_cursors_t;
+
 /* 
  * See xitk_widget_list_[set/get]()
  */
@@ -662,7 +745,7 @@ int xitk_get_window_info(xitk_register_key_t key, window_info_t *winf);
 /*
  * Initialization function, should be the first call to widget lib.
  */
-void xitk_init(Display *display, int verbosity);
+void xitk_init(Display *display, XColor black, int verbosity);
 
 /*
  *
@@ -941,7 +1024,12 @@ void xitk_set_widget_tips_default(xitk_widget_t *w, char *str);
 /**
  *
  */
-void xitk_set_widget_tips_and_timeout(xitk_widget_t *w, char *str, unsigned int timeout);
+void xitk_set_widget_tips_and_timeout(xitk_widget_t *w, char *str, unsigned long timeout);
+
+/**
+ *
+ */
+unsigned long xitk_get_widget_tips_timeout(xitk_widget_t *w);
 
 /**
  *
@@ -1109,15 +1197,19 @@ void *xitk_list_prev_content (xitk_list_t *l);
 void xitk_list_append_content (xitk_list_t *l, void *content);
 
 /**
- * Insert content in list. NOT IMPLEMENTED
+ * Insert content in list.
  */
 void xitk_list_insert_content (xitk_list_t *l, void *content);
 
 /**
- * Remove current content in list. NOT IMPLEMENTED
+ * Remove current content in list.
  */
 void xitk_list_delete_current (xitk_list_t *l);
 
+/**
+ * Return current content
+ */
+xitk_node_t *xitk_list_get_current(xitk_list_t *l);
 
 /*
  * *** Label Buttons
@@ -1449,7 +1541,7 @@ void xitk_mrlbrowser_set_tips_timeout(xitk_widget_t *w, int enabled, unsigned lo
  * define ksym
  * kbuf should be large enought (256 usually)
  */
-int xitk_get_keysym_and_buf(XEvent *event, KeySym *ksym, char kbuf[]);
+int xitk_get_keysym_and_buf(XEvent *event, KeySym *ksym, char kbuf[], int kblen);
 
 /**
  * return keypressed
@@ -2059,6 +2151,11 @@ Window xitk_window_get_window(xitk_window_t *w);
  */
 Pixmap xitk_window_get_background(xitk_window_t *w);
 
+/**
+ *
+ */
+Pixmap xitk_window_get_background_mask(xitk_window_t *w);
+
 /**
  *
  */
@@ -2069,6 +2166,11 @@ void xitk_window_apply_background(ImlibData *im, xitk_window_t *w);
  */
 int xitk_window_change_background(ImlibData *im, xitk_window_t *w, Pixmap bg, int width, int height);
 
+/**
+ *
+ */
+int xitk_window_change_background_with_image(ImlibData *im, xitk_window_t *w, xitk_image_t *img, int width, int height);
+
 /**
  *
  */
@@ -2283,4 +2385,8 @@ void xitk_menu_destroy_sub_branchs(xitk_widget_t *w);
 void xitk_menu_destroy(xitk_widget_t *w);
 int xitk_menu_show_sub_branchs(xitk_widget_t *w);
 
+
+void xitk_cursors_define_window_cursor(Display *display, Window window, xitk_cursors_t cursor);
+void xitk_cursors_restore_window_cursor(Display *display, Window window);
+
 #endif
